@@ -51,10 +51,20 @@ namespace Boo.Lang.Compiler.Ast
 			return new StringLiteralExpression(s);
 		}
 		
+		public static Expression Lift(int i)
+		{
+			return new IntegerLiteralExpression(i);
+		}
+		
 		public static Expression Lift(Expression e)
 		{
 			return e.CloneNode();
 		}
+
+		public static Expression Lift(ParameterDeclaration p)
+		{
+			return new ReferenceExpression(p.LexicalInfo, p.Name);
+		}
 		
 		protected Boo.Lang.Compiler.TypeSystem.IType _expressionType;
 		
