@@ -28,89 +28,95 @@
 
 using System;
 using System.Collections;
+using System.Collections.Generic;
 using Boo.Lang;
 
 namespace Boo.Lang.Compiler.Ast
 {
+	
 	/// <summary>
 	/// Node collection base class.
 	/// </summary>
-	public class NodeCollection : ICollection, ICloneable
+	public class NodeCollection<T> : ICollection, ICloneable, IEnumerable<T>
+		where T : Node
 	{
 		protected Node _parent;
-		
+
 		protected List _list;
 
-		protected NodeCollection() : this(null)
+		protected NodeCollection()
 		{
+			_list = new List();
 		}
 
-		protected NodeCollection(Node parent) : this(parent, new List())
-		{			
-		}
-
-		protected NodeCollection(Node parent, List list)
+		protected NodeCollection(Node parent)
 		{
-			if (null == list)
-			{
-				throw new ArgumentNullException("list");
-			}
 			_parent = parent;
-			_list = list;
+			_list = new List();
+		}
+
+		protected NodeCollection(Node parent, IEnumerable<T> list)
+		{
+			if (null == list) throw new ArgumentNullException("list");
+
+			_parent = parent;
+			_list = new List(list);
+		}
+
+		public T this[int index]
+		{
+			get { return (T)_list[index]; }
+			set { _list[index] = value; }
+		}
+
+		public IEnumerator<T> GetEnumerator()
+		{
+			foreach (T item in _list) yield return item;
 		}
 
 		public int Count
 		{
-			get
-			{
-				return _list.Count;
-			}
+			get { return _list.Count; }
 		}
-		
+
 		public bool IsSynchronized
 		{
-			get
-			{
-				return false;
-			}
+			get { return false; }
 		}
-		
+
 		public object SyncRoot
 		{
-			get
-			{
-				return this;
-			}
+			get { return this; }
 		}
-		
+
 		public void CopyTo(Array array, int index)
 		{
 			_list.CopyTo(array, index);
 		}
-		
-		public IEnumerator GetEnumerator()
+
+		IEnumerator IEnumerable.GetEnumerator()
 		{
 			return _list.GetEnumerator();
 		}
-		
+
 		public void Clear()
-		{			
+		{
 			_list.Clear();
 		}
-		
-		public Node[] ToArray()
+
+		public T[] ToArray()
 		{
-			return (Node[])_list.ToArray(typeof(Node));
+			return (T[])_list.ToArray(new T[_list.Count]);
 		}
-		
-		public Node[] ToReverseArray()
+
+		public T[] ToReverseArray()
 		{
-			Node[] array = ToArray();
+			T[] array = ToArray();
 			Array.Reverse(array);
 			return array;
 		}
-		
-		public Node[] Select(NodeType type)
+
+		public T[] Select(NodeType type)
 		{
 			List result = new List();
 			foreach (Node node in _list)
@@ -120,14 +126,24 @@ namespace Boo.Lang.Compiler.Ast
 					result.Add(node);
 				}
 			}
-			return (Node[])result.ToArray(typeof(Node));
+			return (T[])result.ToArray(new T[result.Count]);
 		}
-		
+
+		protected IEnumerable InternalPopRange(int begin)
+		{
+			return _list.PopRange(begin);
+		}
+
+		public bool ContainsNode(T node)
+		{
+			return _list.ContainsReference(node);
+		}
+
 		public bool Contains(Predicate condition)
 		{
 			return _list.Contains(condition);
 		}
-		
+
 		public bool ContainsEntity(Boo.Lang.Compiler.TypeSystem.IEntity entity)
 		{
 			foreach (Node node in _list)
@@ -139,14 +155,14 @@ namespace Boo.Lang.Compiler.Ast
 			}
 			return false;
 		}
-		
+
 		public Node RemoveByEntity(Boo.Lang.Compiler.TypeSystem.IEntity entity)
 		{
 			if (null == entity)
 			{
 				throw new ArgumentNullException("entity");
 			}
-			for (int i=0; i<_list.Count; ++i)
+			for (int i = 0; i < _list.Count; ++i)
 			{
 				Node node = (Node)_list[i];
 				if (entity == node.Entity)
@@ -157,15 +173,10 @@ namespace Boo.Lang.Compiler.Ast
 			}
 			return null;
 		}
-		
-		public Node GetNodeAt(int index)
-		{
-			return (Node)_list[index];
-		}
-		
+
 		public object Clone()
 		{
-			NodeCollection clone = (NodeCollection)Activator.CreateInstance(GetType());
+			NodeCollection<T> clone = (NodeCollection<T>)Activator.CreateInstance(GetType());
 			List cloneList = clone._list;
 			foreach (Node node in _list)
 			{
@@ -173,7 +184,7 @@ namespace Boo.Lang.Compiler.Ast
 			}
 			return clone;
 		}
-		
+
 		public void ClearTypeSystemBindings()
 		{
 			foreach (Node node in _list)
@@ -181,7 +192,7 @@ namespace Boo.Lang.Compiler.Ast
 				node.ClearTypeSystemBindings();
 			}
 		}
-		
+
 		protected List InnerList
 		{
 			get
@@ -198,14 +209,14 @@ namespace Boo.Lang.Compiler.Ast
 				node.InitializeParent(_parent);
 			}
 		}
-		
+
 		public void Reject(Predicate condition)
 		{
 			if (null == condition)
 			{
 				throw new ArgumentNullException("condition");
 			}
-			
+
 			int index = 0;
 			foreach (Node node in ToArray())
 			{
@@ -219,52 +230,49 @@ namespace Boo.Lang.Compiler.Ast
 				}
 			}
 		}
-		
+
 		public void RemoveAt(int index)
 		{
 			//Node existing = (Node)InnerList[index];
 			//existing.InitializeParent(null);
 			InnerList.RemoveAt(index);
 		}
-		
-		public bool Matches(NodeCollection collection)
+
+		public void ExtendWithClones(IEnumerable<T> items)
 		{
-			if (null == collection) return false;
-			if (Count != collection.Count) return false;
-			for (int i=0; i<Count; ++i)
+			foreach (T item in items)
 			{
-				if (!Node.Matches(GetNodeAt(i), collection.GetNodeAt(i))) return false;
+				InnerList.Add(item.CloneNode());
 			}
-			return true;
 		}
-		
-		internal void ReplaceAt(int i, Node newItem)
+
+		public void ReplaceAt(int i, T newItem)
 		{
 			//Node existing = (Node)InnerList[i];
 			//existing.InitializeParent(null);
 			_list[i] = newItem;
-			Initialize(newItem);			
+			Initialize(newItem);
 		}
 
-		protected void AddNode(Node item)
+		public void Add(T item)
 		{
 			Initialize(item);
 			_list.Add(item);
 		}
 
-		protected void AddNodes(Node[] items)
+		public void Extend(IEnumerable<T> items)
 		{
 			AssertNotNull("items", items);
-			foreach (Node item in items)
+			foreach (T item in items)
 			{
-				AddNode(item);
+				Add(item);
 			}
 		}
 
-		protected bool ReplaceNode(Node existing, Node newItem)
+		public bool Replace(T existing, T newItem)
 		{
-			AssertNotNull("existing", existing);			
-			for (int i=0; i<_list.Count; ++i)
+			AssertNotNull("existing", existing);
+			for (int i = 0; i < _list.Count; ++i)
 			{
 				if (_list[i] == existing)
 				{
@@ -278,12 +286,12 @@ namespace Boo.Lang.Compiler.Ast
 					}
 					return true;
 				}
-			}			
+			}
 			return false;
 		}
 
-		protected void InsertNode(int index, Node item)
-		{			
+		public void Insert(int index, T item)
+		{
 			Initialize(item);
 			InnerList.Insert(index, item);
 		}
@@ -300,21 +308,16 @@ namespace Boo.Lang.Compiler.Ast
 
 		override public bool Equals(object rhs)
 		{
-			NodeCollection other = rhs as NodeCollection;
-			if (null == other)
+			NodeCollection<T> other = rhs as NodeCollection<T>;
+			if (null == other) return false;
+
+			if (InnerList.Count != other.Count) return false;
+
+			IEnumerator<T> enumerator = other.GetEnumerator();
+			foreach (T mine in this)
 			{
-				return false;
-			}
-			if (InnerList.Count != other.Count)
-			{
-				return false;
-			}
-			for (int i=0; i<InnerList.Count; ++i)
-			{
-				if (!InnerList[i].Equals(other.InnerList[i]))
-				{
-					return false;
-				}
+				if (!enumerator.MoveNext()) return false;
+				if (!mine.Equals(enumerator.Current)) return false;
 			}
 			return true;
 		}
@@ -327,7 +330,7 @@ namespace Boo.Lang.Compiler.Ast
 				item.InitializeParent(_parent);
 			}
 		}
-		
+
 		private void AssertNotNull(string descrip, object o)
 		{
 			if (o == null)
@@ -336,6 +339,6 @@ namespace Boo.Lang.Compiler.Ast
 					String.Format("null reference for: {0}", descrip));
 			}
 		}
-		
+
 	}
 }
