@@ -148,14 +148,14 @@ namespace Boo.Lang.Compiler
 			return new CompilerError("BCE0017", SafeLexicalInfo(node), expectedSignature, actualSignature);
 		}
 		
-		public static CompilerError NameNotType(Node node, string name)
+		public static CompilerError NameNotType(Node node, string name, string suggestion)
 		{
-			return new CompilerError("BCE0018", SafeLexicalInfo(node), name);
+			return new CompilerError("BCE0018", SafeLexicalInfo(node), name, DidYouMeanOrNull(suggestion));
 		}
 		
-		public static CompilerError MemberNotFound(MemberReferenceExpression node, string namespace_)
+		public static CompilerError MemberNotFound(MemberReferenceExpression node, string namespace_, string suggestion)
 		{
-			return new CompilerError("BCE0019", SafeLexicalInfo(node), node.Name, namespace_);
+			return new CompilerError("BCE0019", SafeLexicalInfo(node), node.Name, namespace_, DidYouMeanOrNull(suggestion));
 		}
 
 		public static CompilerError InstanceRequired(Node node, string typeName, string memberName)
@@ -369,9 +369,9 @@ namespace Boo.Lang.Compiler
 			return new CompilerError("BCE0063", SafeLexicalInfo(node));
 		}
 		
-		public static CompilerError UnknownAttribute(Node node, string attributeName)
+		public static CompilerError UnknownAttribute(Node node, string attributeName, string suggestion)
 		{
-			return new CompilerError("BCE0064", SafeLexicalInfo(node), attributeName);
+			return new CompilerError("BCE0064", SafeLexicalInfo(node), attributeName, DidYouMeanOrNull(suggestion));
 		}
 		
 		public static CompilerError InvalidIteratorType(Node node, string typeName)
@@ -544,7 +544,7 @@ namespace Boo.Lang.Compiler
 			return new CompilerError("BCE0098", SafeLexicalInfo(node));
 		}
 		
-		public static CompilerError YieldInsideTryBlock(Node node)
+		public static CompilerError YieldInsideTryExceptOrEnsureBlock(Node node)
 		{
 			return new CompilerError("BCE0099", SafeLexicalInfo(node));
 		}
@@ -774,7 +774,67 @@ namespace Boo.Lang.Compiler
 		{
 			return new CompilerError("BCE0144", SafeLexicalInfo(node), memberName, message);
 		}
+
+		public static CompilerError InvalidExceptArgument(Node node, string exceptionType)
+		{
+			return new CompilerError("BCE0145", SafeLexicalInfo(node), exceptionType);
+		}
 		
+		public static CompilerError GenericArgumentMustBeReferenceType(Node node, IGenericParameter parameter, IType argument)
+		{
+			return new CompilerError("BCE0146", SafeLexicalInfo(node), argument, parameter);
+		}
+
+		public static CompilerError GenericArgumentMustBeValueType(Node node, IGenericParameter parameter, IType argument)
+		{
+			return new CompilerError("BCE0147", SafeLexicalInfo(node), argument, parameter);
+		}
+
+		public static CompilerError GenericArgumentMustHaveDefaultConstructor(Node node, IGenericParameter parameter, IType argument)
+		{
+			return new CompilerError("BCE0148", SafeLexicalInfo(node), argument, parameter);
+		}
+
+		public static CompilerError GenericArgumentMustHaveBaseType(Node node, IGenericParameter parameter, IType argument, IType baseType)
+		{
+			return new CompilerError("BCE0149", SafeLexicalInfo(node), argument, parameter, baseType);
+		}
+		
+		public static CompilerError CantBeMarkedFinal(Node node)
+		{
+			return new CompilerError("BCE0150", SafeLexicalInfo(node));
+		}
+		
+		public static CompilerError CantBeMarkedStatic(Node node)
+		{
+			return new CompilerError("BCE0151", SafeLexicalInfo(node));
+		}
+		
+		public static CompilerError ConstructorCantBePolymorphic(Node node, string memberName)
+		{
+			return new CompilerError("BCE0152", SafeLexicalInfo(node), memberName);
+		}
+
+		public static CompilerError InvalidAttributeTarget(Node node, Type attrType, AttributeTargets validOn)
+		{
+			return new CompilerError("BCE0153", SafeLexicalInfo(node), attrType, validOn);
+		}
+
+		public static CompilerError MultipleAttributeUsage(Node node, Type attrType)
+		{
+			return new CompilerError("BCE0154", SafeLexicalInfo(node), attrType);
+		}
+
+		public static CompilerError CannotCreateAnInstanceOfGenericParameterWithoutDefaultConstructorConstraint(Node node, string type)
+		{
+			return new CompilerError("BCE0155", SafeLexicalInfo(node), type);
+		}
+
+		public static CompilerError EventCanOnlyBeInvokedFromWithinDeclaringClass(Node node, IEvent ev)
+		{
+			return new CompilerError("BCE0156", SafeLexicalInfo(node), ev.Name, ev.DeclaringType);
+		}
+
 		public static string ToStringList(System.Collections.IEnumerable names)
 		{
 			StringBuilder builder = new StringBuilder();
@@ -840,5 +900,12 @@ namespace Boo.Lang.Compiler
 			return SafeLexicalInfo(node.ParentNode);
 		}
 
+		private static string DidYouMeanOrNull(string suggestion)
+		{
+			return (null != suggestion)
+				? ResourceManager.Format("BooC.DidYouMean", suggestion)
+				: null;
+		}
+
 	}
 }
