@@ -30,6 +30,7 @@
 
 using System;
 using System.Collections;
+using System.Collections.Generic;
 using System.Diagnostics;
 using System.IO;
 using System.Reflection;
@@ -81,8 +82,13 @@ namespace Boo.Lang.Compiler
 		private string _systemDir;
 
 		private Assembly _booAssembly;
+		
+		private bool _whiteSpaceAgnostic;
 
 		public readonly TraceSwitch TraceSwitch = new TraceSwitch("booc", "boo compiler");
+		
+		private Dictionary<string, string> _defines = new Dictionary<string, string>();
+		
 
 		public CompilerParameters()
 			: this(true)
@@ -128,13 +134,18 @@ namespace Boo.Lang.Compiler
 			//boo.lang.dll
 			_booAssembly = typeof(Boo.Lang.Builtins).Assembly;
 			_assemblyReferences.Add(_booAssembly);
-			//boo.lang.compiler.dll
-			_assemblyReferences.Add(GetType().Assembly);
-
+			
+			//boo.lang.extensions.dll
+			Assembly extensionsAssembly = null;
+			extensionsAssembly = LoadAssembly("Boo.Lang.Extensions", false);
+			if(extensionsAssembly != null)
+				_assemblyReferences.Add(extensionsAssembly);
+				
 			if (TraceSwitch.TraceInfo)
 			{
 				Trace.WriteLine("BOO LANG DLL: " + _booAssembly.Location);
-				Trace.WriteLine("BOO COMPILER DLL: " + GetType().Assembly.Location);
+				Trace.WriteLine("BOO COMPILER EXTENSIONS DLL: " + 
+				                (extensionsAssembly != null ? extensionsAssembly.Location : "NOT FOUND!"));
 			}
 		}
 
@@ -471,5 +482,26 @@ namespace Boo.Lang.Compiler
 
 			set { _delaySign = value; }
 		}
+		
+		public bool WhiteSpaceAgnostic
+		{
+			get
+			{
+				return _whiteSpaceAgnostic;
+			}
+			set
+			{
+				_whiteSpaceAgnostic = value;
+			}
+		}
+		
+		public Dictionary<string, string> Defines
+		{
+			get
+			{
+				return _defines;
+			}
+		}
+		
 	}
-}
\ No newline at end of file
+}
