@@ -105,9 +105,9 @@ namespace Boo.Lang.Compiler.Steps
 			}
 		}
 
-		public override void OnAstLiteralExpression(Boo.Lang.Compiler.Ast.AstLiteralExpression node)
+		public override void OnQuasiquoteExpression(Boo.Lang.Compiler.Ast.QuasiquoteExpression node)
 		{
-			// ignore ast literals
+			// ignore quasi-quotes
 		}
 
 		protected void Bind(Node node, IEntity tag)
@@ -121,16 +121,11 @@ namespace Boo.Lang.Compiler.Steps
 			node.ExpressionType = type;
 		}
 		
-		protected IType GetExpressionType(Expression node)
+		protected virtual IType GetExpressionType(Expression node)
 		{
-			IType type = node.ExpressionType;
-			if (null == type)
-			{
-				throw CompilerErrorFactory.InvalidNode(node);
-			}
-			return type;
+			return TypeSystemServices.GetExpressionType(node);
 		}
-		
+
 		public IEntity GetEntity(Node node)
 		{
 			return TypeSystemServices.GetEntity(node);
