@@ -29,34 +29,6 @@
 
 using System;
 
-#region license
-// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
-// All rights reserved.
-// 
-// Redistribution and use in source and binary forms, with or without modification,
-// are permitted provided that the following conditions are met:
-// 
-//     * Redistributions of source code must retain the above copyright notice,
-//     this list of conditions and the following disclaimer.
-//     * Redistributions in binary form must reproduce the above copyright notice,
-//     this list of conditions and the following disclaimer in the documentation
-//     and/or other materials provided with the distribution.
-//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
-//     contributors may be used to endorse or promote products derived from this
-//     software without specific prior written permission.
-// 
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
-// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#endregion
-
 namespace Boo.Lang.Compiler.Steps
 {
 	using Boo.Lang.Compiler.Ast;
@@ -88,6 +60,10 @@ namespace Boo.Lang.Compiler.Steps
 				TypeMember member = (TypeMember)node;
 				NameResolutionService.Restore((INamespace)TypeSystemServices.GetEntity(member.DeclaringType));
 				CodeBuilder.BindParameterDeclarations(member.IsStatic, node);
+				if (member.IsPrivate && !member.IsSynthetic)
+				{
+					member.Annotate("PrivateMemberNeverUsed", null);
+				}
 			}
 		}
 		
@@ -105,6 +81,10 @@ namespace Boo.Lang.Compiler.Steps
 			if (null == node.Entity)
 			{
 				node.Entity = new InternalField(node);
+				if (node.IsPrivate && !node.IsSynthetic)
+				{
+					node.Annotate("PrivateMemberNeverUsed", null);
+				}
 			}
 		}
 		
@@ -119,7 +99,7 @@ namespace Boo.Lang.Compiler.Steps
 			Visit(node.Getter);
 			Visit(node.Setter);
 			Visit(node.ExplicitInfo);
-		}	
+		}
 
 		override public void OnExplicitMemberInfo(ExplicitMemberInfo node)
 		{
