@@ -33,40 +33,54 @@ namespace Boo.Lang.Compiler.TypeSystem
 	using System.Reflection;
 	using Boo.Lang.Compiler.Ast;
 	using Attribute = Boo.Lang.Compiler.Ast.Attribute;
+	using System.Collections.Generic;
+
+	public abstract class AbstractInternalType : IInternalEntity, IType, INamespace, IGenericTypeInfo
+	{
+		public static readonly IConstructor[] NoConstructors = new IConstructor[0];
 
-	public abstract class AbstractInternalType : IInternalEntity, IType, INamespace
-	{		
 		protected TypeSystemServices _typeSystemServices;
-		
+
 		protected TypeDefinition _typeDefinition;
-		
-		protected IType[] _interfaces;
-		
+
 		protected INamespace _parentNamespace;
-		
-		protected Type _generatedType;
-		
+
+		private string _fullName = null;
+
+		private IGenericParameter[] _genericParameters = null;
+
+		private Dictionary<IType[], IType> _constructedTypes = new Dictionary<IType[], IType>(ArrayEqualityComparer<IType>.Default);
+
 		protected AbstractInternalType(TypeSystemServices typeSystemServices, TypeDefinition typeDefinition)
 		{
 			_typeSystemServices = typeSystemServices;
-			_typeDefinition = typeDefinition;			
+			_typeDefinition = typeDefinition;
 		}
-		
+
+		protected virtual string BuildFullName()
+		{
+			string fullName = _typeDefinition.FullName;
+
+			if (GenericInfo != null)
+			{
+				fullName = string.Format("{0}`{1}", fullName, GenericInfo.GenericParameters.Length);
+			}
+
+			return fullName;
+		}
+
 		public string FullName
 		{
-			get
-			{
-				return _typeDefinition.FullName;
-			}
+			get { return _fullName ?? (_fullName = BuildFullName());  }
 		}
-		
+
 		public string Name
 		{
 			get
 			{
 				return _typeDefinition.Name;
 			}
-		}	
+		}
 
 		public Node Node
 		{
@@ -75,7 +89,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return _typeDefinition;
 			}
 		}
-		
+
 		public IType NestingType
 		{
 			get
@@ -83,7 +97,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return _typeDefinition.ParentNode.Entity as IType;
 			}
 		}
-		
+
 		public virtual INamespace ParentNamespace
 		{
 			get
@@ -95,11 +109,25 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return _parentNamespace;
 			}
 		}
-		
+
 		public virtual bool Resolve(List targetList, string name, EntityType flags)
-		{			
+		{
 			bool found = false;
-			
+
+			// Try to resolve name as a generic parameter
+			if (NameResolutionService.IsFlagSet(flags, EntityType.Type))
+			{
+				foreach (GenericParameterDeclaration gpd in _typeDefinition.GenericParameters)
+				{
+					if (gpd.Name == name)
+					{
+						targetList.AddUnique(gpd.Entity);
+						return true;
+					}
+				}
+			}
+
+			// Try to resolve name as a member
 			foreach (IEntity entity in GetMembers())
 			{
 				if (entity.Name == name && NameResolutionService.IsFlagSet(flags, entity.EntityType))
@@ -108,10 +136,10 @@ namespace Boo.Lang.Compiler.TypeSystem
 					found = true;
 				}
 			}
-			
+
 			return found;
 		}
-		
+
 		public virtual IType BaseType
 		{
 			get
@@ -119,7 +147,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return null;
 			}
 		}
-		
+
 		public TypeDefinition TypeDefinition
 		{
 			get
@@ -127,7 +155,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return _typeDefinition;
 			}
 		}
-		
+
 		public IType Type
 		{
 			get
@@ -135,7 +163,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return this;
 			}
 		}
-		
+
 		public bool IsByRef
 		{
 			get
@@ -143,12 +171,12 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return false;
 			}
 		}
-		
+
 		public IType GetElementType()
 		{
 			return null;
 		}
-		
+
 		public bool IsClass
 		{
 			get
@@ -156,7 +184,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return NodeType.ClassDefinition == _typeDefinition.NodeType;
 			}
 		}
-		
+
 		public bool IsAbstract
 		{
 			get
@@ -164,7 +192,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return _typeDefinition.IsAbstract;
 			}
 		}
-		
+
 		virtual public bool IsFinal
 		{
 			get
@@ -172,7 +200,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return _typeDefinition.IsFinal || IsValueType;
 			}
 		}
-		
+
 		public bool IsInterface
 		{
 			get
@@ -180,7 +208,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return NodeType.InterfaceDefinition == _typeDefinition.NodeType;
 			}
 		}
-		
+
 		public bool IsEnum
 		{
 			get
@@ -188,7 +216,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return NodeType.EnumDefinition == _typeDefinition.NodeType;
 			}
 		}
-		
+
 		virtual public bool IsValueType
 		{
 			get
@@ -196,7 +224,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return false;
 			}
 		}
-		
+
 		public bool IsArray
 		{
 			get
@@ -204,12 +232,12 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return false;
 			}
 		}
-		
+
 		public virtual int GetTypeDepth()
 		{
 			return 1;
 		}
-		
+
 		public IEntity GetDefaultMember()
 		{
 			IType defaultMemberAttribute = _typeSystemServices.Map(Types.DefaultMemberAttribute);
@@ -230,10 +258,10 @@ namespace Boo.Lang.Compiler.TypeSystem
 					}
 				}
 			}
-                        if (_typeDefinition.BaseTypes.Count > 0)
-                        {
+			if (_typeDefinition.BaseTypes.Count > 0)
+			{
 				List buffer = new List();
-				
+
 				foreach (TypeReference baseType in _typeDefinition.BaseTypes)
 				{
 					IType tag = TypeSystemServices.GetType(baseType);
@@ -251,10 +279,10 @@ namespace Boo.Lang.Compiler.TypeSystem
 					}
 				}
 				return NameResolutionService.GetEntityFromList(buffer);
-			} 
+			}
 			return null;
 		}
-		
+
 		public virtual EntityType EntityType
 		{
 			get
@@ -262,117 +290,104 @@ namespace Boo.Lang.Compiler.TypeSystem
 				return EntityType.Type;
 			}
 		}
-		
+
 		public virtual bool IsSubclassOf(IType other)
 		{
 			return false;
 		}
-		
+
 		public virtual bool IsAssignableFrom(IType other)
 		{
 			return this == other ||
 					(!this.IsValueType && Null.Default == other) ||
 					other.IsSubclassOf(this);
 		}
-		
+
 		public virtual IConstructor[] GetConstructors()
 		{
-			return new IConstructor[0];
+			return NoConstructors;
 		}
-		
+
 		public IType[] GetInterfaces()
 		{
-			if (null == _interfaces)
+			List buffer = new List(_typeDefinition.BaseTypes.Count);
+			foreach (TypeReference baseType in _typeDefinition.BaseTypes)
 			{
-				List buffer = new List();
-				
-				foreach (TypeReference baseType in _typeDefinition.BaseTypes)
-				{
-					IType tag = TypeSystemServices.GetType(baseType);
-					if (tag.IsInterface)
-					{
-						buffer.AddUnique(tag);
-					}
-				}
-				
-				_interfaces = (IType[])buffer.ToArray(typeof(IType));
+				IType type = TypeSystemServices.GetType(baseType);
+				if (type.IsInterface) buffer.AddUnique(type);
 			}
-			return _interfaces;
+			return (IType[])buffer.ToArray(new IType[buffer.Count]);
 		}
-		
+
 		public virtual IEntity[] GetMembers()
-		{			
-			ArrayList buffer = new ArrayList();
-			foreach (TypeMember member in _typeDefinition.Members)
-			{
-				buffer.Add(GetMemberEntity(member));
-			}
-			return (IEntity[])buffer.ToArray(typeof(IEntity));
-		}
-		
-		private IEntity GetMemberEntity(TypeMember member)
 		{
-			if (null == member.Entity)
-			{
-				member.Entity = CreateEntity(member);
-			}
-			return member.Entity;
+			return GetMemberEntities(_typeDefinition.Members);
 		}
-		
-		private IEntity CreateEntity(TypeMember member)
+
+		private IEntity[] GetMemberEntities(TypeMemberCollection members)
 		{
-			switch (member.NodeType)
+			IEntity[] entities = new IEntity[members.Count];
+			for (int i = 0; i < entities.Length; ++i)
 			{
-				case NodeType.Field:
-				{
-					return new InternalField((Field)member);
-				}
-					
-				case NodeType.EnumMember:
-				{
-					return new InternalEnumMember(_typeSystemServices, (EnumMember)member);
-				}
-					
-				case NodeType.Method:
-				{
-					return new InternalMethod(_typeSystemServices, (Method)member);
-				}
-					
-				case NodeType.Constructor:
-				{
-					return new InternalConstructor(_typeSystemServices, (Constructor)member);
-				}
-					
-				case NodeType.Property:
-				{
-					return new InternalProperty(_typeSystemServices, (Property)member);
-				}
-					
-				case NodeType.Event:
-				{
-					return new InternalEvent(_typeSystemServices, (Event)member);
-				}
+				entities[i] = _typeSystemServices.GetMemberEntity(members[i]);
 			}
-			throw new ArgumentException("Member type not supported: " + member);
+			return entities;
 		}
-		
-		public Type GeneratedType
-		{
-			get
-			{
-				return _generatedType;
-			}
-			
-			set
-			{
-				_generatedType = value;
-			}
-		}
-		
+
+
 		override public string ToString()
 		{
 			return FullName;
 		}
+
+		public IGenericTypeInfo GenericInfo
+		{
+			get 
+			{
+				if (TypeDefinition.GenericParameters.Count != 0)
+				{
+					return this;
+				}
+				return null;
+			}
+		}
+
+		public IConstructedTypeInfo ConstructedInfo
+		{
+			get { return null; }
+		}
+
+		IGenericParameter[] IGenericTypeInfo.GenericParameters
+		{
+			get
+			{
+				if (_genericParameters == null)
+				{
+					_genericParameters = Array.ConvertAll<GenericParameterDeclaration, IGenericParameter>(
+						_typeDefinition.GenericParameters.ToArray(),
+						delegate(GenericParameterDeclaration gpd) { return (IGenericParameter)gpd.Entity; } );
+				}
+
+				return _genericParameters;
+			}
+		}
+
+		IType IGenericTypeInfo.ConstructType(IType[] arguments)
+		{
+			IType constructed = null;
+			if (!_constructedTypes.TryGetValue(arguments, out constructed))
+			{
+				constructed = CreateConstructedType(arguments);
+				_constructedTypes.Add(arguments, constructed);
+			}
+
+			return constructed;
+		}
+
+		protected virtual IType CreateConstructedType(IType[] arguments)
+		{
+			return new GenericConstructedType(_typeSystemServices, this, arguments);
+		}
 	}
 
 }
