@@ -370,7 +370,14 @@ namespace Boo.Lang.Compiler.TypeSystem
 		{
 			return CreateLocalReference(local.Name, local);
 		}
-		
+
+		public MemberReferenceExpression CreateReference(LexicalInfo li, Field field)
+		{
+			MemberReferenceExpression e = CreateReference(field);
+			e.LexicalInfo = li;
+			return e;
+		}
+
 		public MemberReferenceExpression CreateReference(Field field)
 		{
 			return CreateReference((IField)field.Entity);
@@ -406,12 +413,18 @@ namespace Boo.Lang.Compiler.TypeSystem
 		}
 
 		public MemberReferenceExpression CreateMemberReference(Expression target, IMember member)
+		{
+			MemberReferenceExpression reference = MemberReferenceForEntity(target, member);
+			reference.ExpressionType = member.Type;
+			return reference;
+		}
+
+		public MemberReferenceExpression MemberReferenceForEntity(Expression target, IEntity entity)
 		{
 			MemberReferenceExpression reference = new MemberReferenceExpression(target.LexicalInfo);
 			reference.Target = target;
-			reference.Name = member.Name;
-			reference.Entity = member;
-			reference.ExpressionType = member.Type;
+			reference.Name = entity.Name;
+			reference.Entity = entity;
 			return reference;
 		}
 
