@@ -111,7 +111,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 			{
 				return false;
 			}
-			return Equals(_parameters, rhs._parameters);
+			return AreSameParameters(_parameters, rhs._parameters);
 		}
 		
 		override public string ToString()
@@ -122,14 +122,14 @@ namespace Boo.Lang.Compiler.TypeSystem
 				if (i > 0) { buffer.Append(", "); }
 				if (_parameters[i].IsByRef) buffer.Append("ref ");
 				if (_acceptVarArgs && i == _parameters.Length-1) buffer.Append('*');
-				buffer.Append(_parameters[i].Type.FullName);
+				buffer.Append(_parameters[i].Type.ToString());
 			}
 			buffer.Append(") as ");
-			buffer.Append(_returnType.FullName);
+			buffer.Append(_returnType.ToString());
 			return buffer.ToString();
 		}
 		
-		bool Equals(IParameter[] lhs, IParameter[] rhs)
+		static public bool AreSameParameters(IParameter[] lhs, IParameter[] rhs)
 		{
 			if (lhs.Length != rhs.Length)
 			{
