@@ -100,7 +100,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 		
 		public ExternalType TimeSpanType;
 		
-		public ExternalType DateTimeType;
+		protected ExternalType DateTimeType;
 		
 		public ExternalType RuntimeServicesType;
 		
@@ -128,6 +128,8 @@ namespace Boo.Lang.Compiler.TypeSystem
 		
 		public ExternalType SystemAttribute;
 		
+		public ExternalType ConditionalAttribute;
+		
 		protected Hashtable _primitives = new Hashtable();
 		
 		protected Hashtable _entityCache = new Hashtable();
@@ -138,17 +140,19 @@ namespace Boo.Lang.Compiler.TypeSystem
 		
 		public readonly BooCodeBuilder CodeBuilder;
 		
-		StringBuilder _buffer = new StringBuilder();
+		private StringBuilder _buffer = new StringBuilder();
 		
-		Module _compilerGeneratedTypesModule;
+		private Module _compilerGeneratedTypesModule;
 
-		Module _compilerGeneratedExtensionsModule;
+		private Module _compilerGeneratedExtensionsModule;
 
-		ClassDefinition _compilerGeneratedExtensionsClass;
+		private ClassDefinition _compilerGeneratedExtensionsClass;
 		
 		protected readonly CompilerContext _context;
 
-		private readonly AnonymousCallablesManager _anonymousCallablesManager; 
+		private readonly AnonymousCallablesManager _anonymousCallablesManager;
+
+		private readonly GenericsServices _genericsServices;
 		
 		public TypeSystemServices() : this(new CompilerContext())
 		{
@@ -156,13 +160,11 @@ namespace Boo.Lang.Compiler.TypeSystem
 		
 		public TypeSystemServices(CompilerContext context)
 		{
-			if (null == context)
-			{
-				throw new ArgumentNullException("context");
-			}
+			if (null == context) throw new ArgumentNullException("context");
 			
 			_context = context;
 			_anonymousCallablesManager = new AnonymousCallablesManager(this);
+			_genericsServices = new GenericsServices(context);
 
 			CodeBuilder = new BooCodeBuilder(this);
 			
@@ -207,7 +209,8 @@ namespace Boo.Lang.Compiler.TypeSystem
 			Cache(UIntPtrType = new ExternalType(this, Types.UIntPtr));
 			Cache(MulticastDelegateType = new ExternalType(this, Types.MulticastDelegate));
 			Cache(DelegateType = new ExternalType(this, Types.Delegate));
-			Cache(SystemAttribute = new ExternalType(this, typeof(System.Attribute)));			
+			Cache(SystemAttribute = new ExternalType(this, typeof(System.Attribute)));
+			Cache(ConditionalAttribute = new ExternalType(this, typeof(System.Diagnostics.ConditionalAttribute)));
 			Cache(IEnumerableGenericType = new ExternalType(this, typeof(System.Collections.Generic.IEnumerable<>)));
 			Cache(IEnumeratorGenericType = new ExternalType(this, typeof(System.Collections.Generic.IEnumerator<>)));
 
@@ -215,14 +218,17 @@ namespace Boo.Lang.Compiler.TypeSystem
 
 			PreparePrimitives();
 			PrepareBuiltinFunctions();
+
 		}
 		
 		public CompilerContext Context
 		{
-			get
-			{
-				return _context;
+			get { return _context; }
 			}
+
+		public GenericsServices GenericsServices
+		{
+			get { return _genericsServices; }
 		}
 		
 		public IType GetMostGenericType(IType current, IType candidate)
@@ -450,18 +456,24 @@ namespace Boo.Lang.Compiler.TypeSystem
 		
 		public IType GetEnumeratorItemType(IType iteratorType)
 		{
+			// Arrays are enumerators of their element type
 			if (iteratorType.IsArray) return iteratorType.GetElementType();
+
+			// String are enumerators of char
 			if (StringType == iteratorType) return CharType;
 			
+			// Try to use an EnumerableItemType attribute 
 			if (iteratorType.IsClass)
 			{
 				IType enumeratorItemType = GetEnumeratorItemTypeFromAttribute(iteratorType);
 				if (null != enumeratorItemType) return enumeratorItemType;
 			}
 
+			// Try to use a generic IEnumerable interface
 			IType genericItemType = GetGenericEnumerableItemType(iteratorType);
 			if (null != genericItemType) return genericItemType;
 
+			// If none of these work, the type is an enumerator of object
 			return ObjectType;
 		}
 		
@@ -670,53 +682,41 @@ namespace Boo.Lang.Compiler.TypeSystem
 		
 		public bool IsCallableTypeAssignableFrom(ICallableType lhs, IType rhs)
 		{
-			if (lhs == rhs || Null.Default == rhs)
-			{
-				return true;
-			}
+			if (lhs == rhs) return true;
+			if (Null.Default == rhs) return true;
 			
 			ICallableType other = rhs as ICallableType;
-			if (null != other)
-			{
+			if (null == other) return false;
+
 				CallableSignature lvalue = lhs.GetSignature();
 				CallableSignature rvalue = other.GetSignature();
-				if (lvalue == rvalue)
-				{
-					return true;
-				}
+			if (lvalue == rvalue) return true;
 				
 				IParameter[] lparams = lvalue.Parameters;
 				IParameter[] rparams = rvalue.Parameters;
-				if (lparams.Length >= rparams.Length)
-				{
+			if (lparams.Length < rparams.Length) return false;
+
 					for (int i=0; i<rparams.Length; ++i)
 					{
-						IType lparamType = lparams[i].Type;
-						IType rparamType = rparams[i].Type;
-						if (!AreTypesRelated(lparamType, rparamType))
-						{	
-							return false;
+				if (!AreTypesRelated(lparams[i].Type, rparams[i].Type)) return false;
 						}
+
+			return CompatibleReturnTypes(lvalue, rvalue);
 					}
 					
-					if (VoidType != lvalue.ReturnType &&
-						VoidType != rvalue.ReturnType)
+		private bool CompatibleReturnTypes(CallableSignature lvalue, CallableSignature rvalue)
 					{
+			if (VoidType != lvalue.ReturnType && VoidType != rvalue.ReturnType)
+			{
 						return AreTypesRelated(lvalue.ReturnType, rvalue.ReturnType);
 					}
 					
 					return true;
 				}
-			}
 			
-			return false;
-		}
-		
 		public static bool CheckOverrideSignature(IMethod impl, IMethod baseMethod)
 		{
-			IParameter[] implParameters = impl.GetParameters();
-			IParameter[] baseParameters = baseMethod.GetParameters();
-			return CheckOverrideSignature(implParameters, baseParameters);
+			return CheckOverrideSignature(impl.GetParameters(), baseMethod.GetParameters());
 		}
 
 		public static bool CheckOverrideSignature(IParameter[] implParameters, IParameter[] baseParameters)
@@ -886,10 +886,7 @@ namespace Boo.Lang.Compiler.TypeSystem
 		
 		private static void GetAllMembers(List members, INamespace entity)
 		{
-			if (null == entity)
-			{
-				return;
-			}
+			if (null == entity) return;
 			
 			IType type = entity as IType;
 			if (null != type)
@@ -1273,7 +1270,7 @@ namespace Boo.Lang.Compiler.TypeSystem
                 return GetExternalEnumeratorItemType(iteratorType);
             }
 
-            // If iterator type is a generic constructed type map its attribute from its definition
+            // If iterator type is a generic constructed type, map its attribute from its definition
             GenericConstructedType constructedType = iteratorType as GenericConstructedType;
             if (constructedType != null)
             {
@@ -1297,18 +1294,15 @@ namespace Boo.Lang.Compiler.TypeSystem
 			}
 			return null;
 		}
-		
 
 		public IType GetGenericEnumerableItemType(IType iteratorType)		
 		{
-			// Arrays implicitly implement IEnumerable<elementType>
+			// Arrays implicitly implement IEnumerable[of element type]
 			if (iteratorType is ArrayType) return iteratorType.GetElementType();
 			
-			// If type is not an array, try to find IEnumerable<T> in its interfaces
-			IType genericEnumerable = IEnumerableGenericType;			
-
+			// If type is not an array, try to find IEnumerable[of some type] in its interfaces
 			IType itemType = null;
-			foreach (IType type in FindConstructedTypes(iteratorType, genericEnumerable))
+			foreach (IType type in GenericsServices.FindConstructedTypes(iteratorType, IEnumerableGenericType))
 			{
 				IType candidateItemType = type.ConstructedInfo.GenericArguments[0];				
 				
@@ -1324,52 +1318,6 @@ namespace Boo.Lang.Compiler.TypeSystem
 			
 			return itemType;
 		}
-		
-		public System.Collections.Generic.IEnumerable<IType> FindConstructedTypes(IType type, IType definition)
-		{	
-			while (type != null)
-			{			
-				if (type.ConstructedInfo != null && 
-				    type.ConstructedInfo.GenericDefinition == definition)
-				{
-					yield return type;
-				}
-
-				IType[] interfaces = type.GetInterfaces();
-				if (interfaces != null)
-				{
-					foreach (IType interfaceType in interfaces)
-					{
-						foreach (IType match in FindConstructedTypes(interfaceType, definition))
-						{
-							yield return match;
-						}
-					}
-				}
-								
-				type = type.BaseType;
-			}
-		}
-		
-		public static bool IsOpenGenericType(IType type)
-		{
-			if (type is IGenericParameter)
-			{
-				return true;
-			}
-			
-			if (type.ConstructedInfo != null)
-			{
-				return !type.ConstructedInfo.FullyConstructed;
-			}
-			
-			if (type.IsByRef || type.IsArray)
-			{
-				return IsOpenGenericType(type.GetElementType());
-			}
-			
-			return false;
-		}
 						                                         
 		public IEntity GetMemberEntity(TypeMember member)
 		{
