@@ -88,111 +88,112 @@ namespace Boo.Lang.Parser
 		public const int ENUM = 26;
 		public const int EVENT = 27;
 		public const int EXCEPT = 28;
-		public const int FINAL = 29;
-		public const int FROM = 30;
-		public const int FOR = 31;
-		public const int FALSE = 32;
-		public const int GET = 33;
-		public const int GOTO = 34;
-		public const int IMPORT = 35;
-		public const int INTERFACE = 36;
-		public const int INTERNAL = 37;
-		public const int IS = 38;
-		public const int ISA = 39;
-		public const int IF = 40;
-		public const int IN = 41;
-		public const int NOT = 42;
-		public const int NULL = 43;
-		public const int OF = 44;
-		public const int OR = 45;
-		public const int OVERRIDE = 46;
-		public const int PASS = 47;
-		public const int NAMESPACE = 48;
-		public const int PARTIAL = 49;
-		public const int PUBLIC = 50;
-		public const int PROTECTED = 51;
-		public const int PRIVATE = 52;
-		public const int RAISE = 53;
-		public const int REF = 54;
-		public const int RETURN = 55;
-		public const int SET = 56;
-		public const int SELF = 57;
-		public const int SUPER = 58;
-		public const int STATIC = 59;
-		public const int STRUCT = 60;
-		public const int TRY = 61;
-		public const int TRANSIENT = 62;
-		public const int TRUE = 63;
-		public const int TYPEOF = 64;
-		public const int UNLESS = 65;
-		public const int VIRTUAL = 66;
-		public const int WHILE = 67;
-		public const int YIELD = 68;
-		public const int TRIPLE_QUOTED_STRING = 69;
-		public const int EOS = 70;
-		public const int DOUBLE_QUOTED_STRING = 71;
-		public const int SINGLE_QUOTED_STRING = 72;
-		public const int ID = 73;
-		public const int LBRACK = 74;
-		public const int RBRACK = 75;
-		public const int LPAREN = 76;
-		public const int RPAREN = 77;
-		public const int ASSIGN = 78;
-		public const int SUBTRACT = 79;
-		public const int COMMA = 80;
-		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 81;
-		public const int SPLICE_BEGIN = 82;
-		public const int DOT = 83;
-		public const int COLON = 84;
-		public const int MULTIPLY = 85;
-		public const int BITWISE_OR = 86;
-		public const int LBRACE = 87;
-		public const int RBRACE = 88;
-		public const int QQ_BEGIN = 89;
-		public const int QQ_END = 90;
-		public const int INPLACE_BITWISE_OR = 91;
-		public const int INPLACE_BITWISE_AND = 92;
-		public const int INPLACE_SHIFT_LEFT = 93;
-		public const int INPLACE_SHIFT_RIGHT = 94;
-		public const int CMP_OPERATOR = 95;
-		public const int GREATER_THAN = 96;
-		public const int LESS_THAN = 97;
-		public const int ADD = 98;
-		public const int EXCLUSIVE_OR = 99;
-		public const int DIVISION = 100;
-		public const int MODULUS = 101;
-		public const int BITWISE_AND = 102;
-		public const int SHIFT_LEFT = 103;
-		public const int SHIFT_RIGHT = 104;
-		public const int EXPONENTIATION = 105;
-		public const int INCREMENT = 106;
-		public const int DECREMENT = 107;
-		public const int ONES_COMPLEMENT = 108;
-		public const int INT = 109;
-		public const int LONG = 110;
-		public const int RE_LITERAL = 111;
-		public const int DOUBLE = 112;
-		public const int FLOAT = 113;
-		public const int TIMESPAN = 114;
-		public const int LINE_CONTINUATION = 115;
-		public const int SL_COMMENT = 116;
-		public const int ML_COMMENT = 117;
-		public const int WS = 118;
-		public const int X_RE_LITERAL = 119;
-		public const int NEWLINE = 120;
-		public const int ESCAPED_EXPRESSION = 121;
-		public const int DQS_ESC = 122;
-		public const int SQS_ESC = 123;
-		public const int SESC = 124;
-		public const int RE_CHAR = 125;
-		public const int X_RE_CHAR = 126;
-		public const int RE_ESC = 127;
-		public const int DIGIT_GROUP = 128;
-		public const int REVERSE_DIGIT_GROUP = 129;
-		public const int ID_PREFIX = 130;
-		public const int ID_LETTER = 131;
-		public const int DIGIT = 132;
-		public const int HEXDIGIT = 133;
+		public const int FAILURE = 29;
+		public const int FINAL = 30;
+		public const int FROM = 31;
+		public const int FOR = 32;
+		public const int FALSE = 33;
+		public const int GET = 34;
+		public const int GOTO = 35;
+		public const int IMPORT = 36;
+		public const int INTERFACE = 37;
+		public const int INTERNAL = 38;
+		public const int IS = 39;
+		public const int ISA = 40;
+		public const int IF = 41;
+		public const int IN = 42;
+		public const int NOT = 43;
+		public const int NULL = 44;
+		public const int OF = 45;
+		public const int OR = 46;
+		public const int OVERRIDE = 47;
+		public const int PASS = 48;
+		public const int NAMESPACE = 49;
+		public const int PARTIAL = 50;
+		public const int PUBLIC = 51;
+		public const int PROTECTED = 52;
+		public const int PRIVATE = 53;
+		public const int RAISE = 54;
+		public const int REF = 55;
+		public const int RETURN = 56;
+		public const int SET = 57;
+		public const int SELF = 58;
+		public const int SUPER = 59;
+		public const int STATIC = 60;
+		public const int STRUCT = 61;
+		public const int TRY = 62;
+		public const int TRANSIENT = 63;
+		public const int TRUE = 64;
+		public const int TYPEOF = 65;
+		public const int UNLESS = 66;
+		public const int VIRTUAL = 67;
+		public const int WHILE = 68;
+		public const int YIELD = 69;
+		public const int TRIPLE_QUOTED_STRING = 70;
+		public const int EOS = 71;
+		public const int DOUBLE_QUOTED_STRING = 72;
+		public const int SINGLE_QUOTED_STRING = 73;
+		public const int ID = 74;
+		public const int LBRACK = 75;
+		public const int RBRACK = 76;
+		public const int LPAREN = 77;
+		public const int RPAREN = 78;
+		public const int ASSIGN = 79;
+		public const int SUBTRACT = 80;
+		public const int COMMA = 81;
+		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 82;
+		public const int SPLICE_BEGIN = 83;
+		public const int DOT = 84;
+		public const int COLON = 85;
+		public const int MULTIPLY = 86;
+		public const int BITWISE_OR = 87;
+		public const int LBRACE = 88;
+		public const int RBRACE = 89;
+		public const int QQ_BEGIN = 90;
+		public const int QQ_END = 91;
+		public const int INPLACE_BITWISE_OR = 92;
+		public const int INPLACE_BITWISE_AND = 93;
+		public const int INPLACE_SHIFT_LEFT = 94;
+		public const int INPLACE_SHIFT_RIGHT = 95;
+		public const int CMP_OPERATOR = 96;
+		public const int GREATER_THAN = 97;
+		public const int LESS_THAN = 98;
+		public const int ADD = 99;
+		public const int EXCLUSIVE_OR = 100;
+		public const int DIVISION = 101;
+		public const int MODULUS = 102;
+		public const int BITWISE_AND = 103;
+		public const int SHIFT_LEFT = 104;
+		public const int SHIFT_RIGHT = 105;
+		public const int EXPONENTIATION = 106;
+		public const int INCREMENT = 107;
+		public const int DECREMENT = 108;
+		public const int ONES_COMPLEMENT = 109;
+		public const int INT = 110;
+		public const int LONG = 111;
+		public const int RE_LITERAL = 112;
+		public const int DOUBLE = 113;
+		public const int FLOAT = 114;
+		public const int TIMESPAN = 115;
+		public const int LINE_CONTINUATION = 116;
+		public const int SL_COMMENT = 117;
+		public const int ML_COMMENT = 118;
+		public const int WS = 119;
+		public const int X_RE_LITERAL = 120;
+		public const int NEWLINE = 121;
+		public const int ESCAPED_EXPRESSION = 122;
+		public const int DQS_ESC = 123;
+		public const int SQS_ESC = 124;
+		public const int SESC = 125;
+		public const int RE_CHAR = 126;
+		public const int X_RE_CHAR = 127;
+		public const int RE_ESC = 128;
+		public const int DIGIT_GROUP = 129;
+		public const int REVERSE_DIGIT_GROUP = 130;
+		public const int ID_PREFIX = 131;
+		public const int ID_LETTER = 132;
+		public const int DIGIT = 133;
+		public const int HEXDIGIT = 134;
 		
 		
 	
@@ -226,65 +227,66 @@ namespace Boo.Lang.Parser
 			caseSensitiveLiterals = true;
 			setCaseSensitive(true);
 			literals = new Hashtable(100, (float) 0.4, null, Comparer.Default);
-			literals.Add("public", 50);
-			literals.Add("namespace", 48);
+			literals.Add("public", 51);
+			literals.Add("namespace", 49);
 			literals.Add("break", 13);
-			literals.Add("while", 67);
-			literals.Add("raise", 53);
-			literals.Add("typeof", 64);
+			literals.Add("while", 68);
+			literals.Add("raise", 54);
+			literals.Add("typeof", 65);
 			literals.Add("and", 11);
-			literals.Add("not", 42);
-			literals.Add("return", 55);
-			literals.Add("pass", 47);
-			literals.Add("from", 30);
-			literals.Add("null", 43);
+			literals.Add("failure", 29);
+			literals.Add("not", 43);
+			literals.Add("return", 56);
+			literals.Add("pass", 48);
+			literals.Add("from", 31);
+			literals.Add("null", 44);
 			literals.Add("def", 20);
-			literals.Add("protected", 51);
-			literals.Add("ref", 54);
+			literals.Add("protected", 52);
+			literals.Add("ref", 55);
 			literals.Add("class", 18);
 			literals.Add("do", 22);
 			literals.Add("except", 28);
 			literals.Add("event", 27);
-			literals.Add("unless", 65);
-			literals.Add("super", 58);
-			literals.Add("set", 56);
-			literals.Add("transient", 62);
+			literals.Add("unless", 66);
+			literals.Add("super", 59);
+			literals.Add("set", 57);
+			literals.Add("transient", 63);
 			literals.Add("constructor", 19);
-			literals.Add("interface", 36);
-			literals.Add("of", 44);
-			literals.Add("is", 38);
-			literals.Add("internal", 37);
-			literals.Add("final", 29);
-			literals.Add("yield", 68);
-			literals.Add("or", 45);
+			literals.Add("interface", 37);
+			literals.Add("of", 45);
+			literals.Add("is", 39);
+			literals.Add("internal", 38);
+			literals.Add("final", 30);
+			literals.Add("yield", 69);
+			literals.Add("or", 46);
 			literals.Add("destructor", 21);
-			literals.Add("if", 40);
-			literals.Add("override", 46);
+			literals.Add("if", 41);
+			literals.Add("override", 47);
 			literals.Add("as", 12);
-			literals.Add("try", 61);
-			literals.Add("goto", 34);
+			literals.Add("try", 62);
+			literals.Add("goto", 35);
 			literals.Add("enum", 26);
-			literals.Add("isa", 39);
-			literals.Add("for", 31);
+			literals.Add("isa", 40);
+			literals.Add("for", 32);
 			literals.Add("char", 17);
-			literals.Add("private", 52);
-			literals.Add("false", 32);
-			literals.Add("static", 59);
+			literals.Add("private", 53);
+			literals.Add("false", 33);
+			literals.Add("static", 60);
 			literals.Add("abstract", 10);
-			literals.Add("partial", 49);
+			literals.Add("partial", 50);
 			literals.Add("callable", 15);
-			literals.Add("get", 33);
+			literals.Add("get", 34);
 			literals.Add("continue", 14);
 			literals.Add("cast", 16);
-			literals.Add("struct", 60);
+			literals.Add("struct", 61);
 			literals.Add("else", 24);
-			literals.Add("import", 35);
+			literals.Add("import", 36);
 			literals.Add("elif", 23);
-			literals.Add("in", 41);
-			literals.Add("self", 57);
+			literals.Add("in", 42);
+			literals.Add("self", 58);
 			literals.Add("ensure", 25);
-			literals.Add("true", 63);
-			literals.Add("virtual", 66);
+			literals.Add("true", 64);
+			literals.Add("virtual", 67);
 		}
 		
 		override public IToken nextToken()			//throws TokenStreamException
