@@ -90,111 +90,112 @@ using Boo.Lang.Parser.Util;
 		public const int ENUM = 26;
 		public const int EVENT = 27;
 		public const int EXCEPT = 28;
-		public const int FINAL = 29;
-		public const int FROM = 30;
-		public const int FOR = 31;
-		public const int FALSE = 32;
-		public const int GET = 33;
-		public const int GOTO = 34;
-		public const int IMPORT = 35;
-		public const int INTERFACE = 36;
-		public const int INTERNAL = 37;
-		public const int IS = 38;
-		public const int ISA = 39;
-		public const int IF = 40;
-		public const int IN = 41;
-		public const int NOT = 42;
-		public const int NULL = 43;
-		public const int OF = 44;
-		public const int OR = 45;
-		public const int OVERRIDE = 46;
-		public const int PASS = 47;
-		public const int NAMESPACE = 48;
-		public const int PARTIAL = 49;
-		public const int PUBLIC = 50;
-		public const int PROTECTED = 51;
-		public const int PRIVATE = 52;
-		public const int RAISE = 53;
-		public const int REF = 54;
-		public const int RETURN = 55;
-		public const int SET = 56;
-		public const int SELF = 57;
-		public const int SUPER = 58;
-		public const int STATIC = 59;
-		public const int STRUCT = 60;
-		public const int TRY = 61;
-		public const int TRANSIENT = 62;
-		public const int TRUE = 63;
-		public const int TYPEOF = 64;
-		public const int UNLESS = 65;
-		public const int VIRTUAL = 66;
-		public const int WHILE = 67;
-		public const int YIELD = 68;
-		public const int TRIPLE_QUOTED_STRING = 69;
-		public const int EOS = 70;
-		public const int DOUBLE_QUOTED_STRING = 71;
-		public const int SINGLE_QUOTED_STRING = 72;
-		public const int ID = 73;
-		public const int LBRACK = 74;
-		public const int RBRACK = 75;
-		public const int LPAREN = 76;
-		public const int RPAREN = 77;
-		public const int ASSIGN = 78;
-		public const int SUBTRACT = 79;
-		public const int COMMA = 80;
-		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 81;
-		public const int SPLICE_BEGIN = 82;
-		public const int DOT = 83;
-		public const int COLON = 84;
-		public const int MULTIPLY = 85;
-		public const int BITWISE_OR = 86;
-		public const int LBRACE = 87;
-		public const int RBRACE = 88;
-		public const int QQ_BEGIN = 89;
-		public const int QQ_END = 90;
-		public const int INPLACE_BITWISE_OR = 91;
-		public const int INPLACE_BITWISE_AND = 92;
-		public const int INPLACE_SHIFT_LEFT = 93;
-		public const int INPLACE_SHIFT_RIGHT = 94;
-		public const int CMP_OPERATOR = 95;
-		public const int GREATER_THAN = 96;
-		public const int LESS_THAN = 97;
-		public const int ADD = 98;
-		public const int EXCLUSIVE_OR = 99;
-		public const int DIVISION = 100;
-		public const int MODULUS = 101;
-		public const int BITWISE_AND = 102;
-		public const int SHIFT_LEFT = 103;
-		public const int SHIFT_RIGHT = 104;
-		public const int EXPONENTIATION = 105;
-		public const int INCREMENT = 106;
-		public const int DECREMENT = 107;
-		public const int ONES_COMPLEMENT = 108;
-		public const int INT = 109;
-		public const int LONG = 110;
-		public const int RE_LITERAL = 111;
-		public const int DOUBLE = 112;
-		public const int FLOAT = 113;
-		public const int TIMESPAN = 114;
-		public const int LINE_CONTINUATION = 115;
-		public const int SL_COMMENT = 116;
-		public const int ML_COMMENT = 117;
-		public const int WS = 118;
-		public const int X_RE_LITERAL = 119;
-		public const int NEWLINE = 120;
-		public const int ESCAPED_EXPRESSION = 121;
-		public const int DQS_ESC = 122;
-		public const int SQS_ESC = 123;
-		public const int SESC = 124;
-		public const int RE_CHAR = 125;
-		public const int X_RE_CHAR = 126;
-		public const int RE_ESC = 127;
-		public const int DIGIT_GROUP = 128;
-		public const int REVERSE_DIGIT_GROUP = 129;
-		public const int ID_PREFIX = 130;
-		public const int ID_LETTER = 131;
-		public const int DIGIT = 132;
-		public const int HEXDIGIT = 133;
+		public const int FAILURE = 29;
+		public const int FINAL = 30;
+		public const int FROM = 31;
+		public const int FOR = 32;
+		public const int FALSE = 33;
+		public const int GET = 34;
+		public const int GOTO = 35;
+		public const int IMPORT = 36;
+		public const int INTERFACE = 37;
+		public const int INTERNAL = 38;
+		public const int IS = 39;
+		public const int ISA = 40;
+		public const int IF = 41;
+		public const int IN = 42;
+		public const int NOT = 43;
+		public const int NULL = 44;
+		public const int OF = 45;
+		public const int OR = 46;
+		public const int OVERRIDE = 47;
+		public const int PASS = 48;
+		public const int NAMESPACE = 49;
+		public const int PARTIAL = 50;
+		public const int PUBLIC = 51;
+		public const int PROTECTED = 52;
+		public const int PRIVATE = 53;
+		public const int RAISE = 54;
+		public const int REF = 55;
+		public const int RETURN = 56;
+		public const int SET = 57;
+		public const int SELF = 58;
+		public const int SUPER = 59;
+		public const int STATIC = 60;
+		public const int STRUCT = 61;
+		public const int TRY = 62;
+		public const int TRANSIENT = 63;
+		public const int TRUE = 64;
+		public const int TYPEOF = 65;
+		public const int UNLESS = 66;
+		public const int VIRTUAL = 67;
+		public const int WHILE = 68;
+		public const int YIELD = 69;
+		public const int TRIPLE_QUOTED_STRING = 70;
+		public const int EOS = 71;
+		public const int DOUBLE_QUOTED_STRING = 72;
+		public const int SINGLE_QUOTED_STRING = 73;
+		public const int ID = 74;
+		public const int LBRACK = 75;
+		public const int RBRACK = 76;
+		public const int LPAREN = 77;
+		public const int RPAREN = 78;
+		public const int ASSIGN = 79;
+		public const int SUBTRACT = 80;
+		public const int COMMA = 81;
+		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 82;
+		public const int SPLICE_BEGIN = 83;
+		public const int DOT = 84;
+		public const int COLON = 85;
+		public const int MULTIPLY = 86;
+		public const int BITWISE_OR = 87;
+		public const int LBRACE = 88;
+		public const int RBRACE = 89;
+		public const int QQ_BEGIN = 90;
+		public const int QQ_END = 91;
+		public const int INPLACE_BITWISE_OR = 92;
+		public const int INPLACE_BITWISE_AND = 93;
+		public const int INPLACE_SHIFT_LEFT = 94;
+		public const int INPLACE_SHIFT_RIGHT = 95;
+		public const int CMP_OPERATOR = 96;
+		public const int GREATER_THAN = 97;
+		public const int LESS_THAN = 98;
+		public const int ADD = 99;
+		public const int EXCLUSIVE_OR = 100;
+		public const int DIVISION = 101;
+		public const int MODULUS = 102;
+		public const int BITWISE_AND = 103;
+		public const int SHIFT_LEFT = 104;
+		public const int SHIFT_RIGHT = 105;
+		public const int EXPONENTIATION = 106;
+		public const int INCREMENT = 107;
+		public const int DECREMENT = 108;
+		public const int ONES_COMPLEMENT = 109;
+		public const int INT = 110;
+		public const int LONG = 111;
+		public const int RE_LITERAL = 112;
+		public const int DOUBLE = 113;
+		public const int FLOAT = 114;
+		public const int TIMESPAN = 115;
+		public const int LINE_CONTINUATION = 116;
+		public const int SL_COMMENT = 117;
+		public const int ML_COMMENT = 118;
+		public const int WS = 119;
+		public const int X_RE_LITERAL = 120;
+		public const int NEWLINE = 121;
+		public const int ESCAPED_EXPRESSION = 122;
+		public const int DQS_ESC = 123;
+		public const int SQS_ESC = 124;
+		public const int SESC = 125;
+		public const int RE_CHAR = 126;
+		public const int X_RE_CHAR = 127;
+		public const int RE_ESC = 128;
+		public const int DIGIT_GROUP = 129;
+		public const int REVERSE_DIGIT_GROUP = 130;
+		public const int ID_PREFIX = 131;
+		public const int ID_LETTER = 132;
+		public const int DIGIT = 133;
+		public const int HEXDIGIT = 134;
 		
 		
 	protected int _skipWhitespaceRegion = 0;
@@ -276,65 +277,66 @@ using Boo.Lang.Parser.Util;
 			caseSensitiveLiterals = true;
 			setCaseSensitive(true);
 			literals = new Hashtable(100, (float) 0.4, null, Comparer.Default);
-			literals.Add("public", 50);
-			literals.Add("namespace", 48);
+			literals.Add("public", 51);
+			literals.Add("namespace", 49);
 			literals.Add("break", 13);
-			literals.Add("while", 67);
-			literals.Add("raise", 53);
-			literals.Add("typeof", 64);
+			literals.Add("while", 68);
+			literals.Add("raise", 54);
+			literals.Add("typeof", 65);
 			literals.Add("and", 11);
-			literals.Add("not", 42);
-			literals.Add("return", 55);
-			literals.Add("pass", 47);
-			literals.Add("from", 30);
-			literals.Add("null", 43);
+			literals.Add("failure", 29);
+			literals.Add("not", 43);
+			literals.Add("return", 56);
+			literals.Add("pass", 48);
+			literals.Add("from", 31);
+			literals.Add("null", 44);
 			literals.Add("def", 20);
-			literals.Add("protected", 51);
-			literals.Add("ref", 54);
+			literals.Add("protected", 52);
+			literals.Add("ref", 55);
 			literals.Add("class", 18);
 			literals.Add("do", 22);
 			literals.Add("except", 28);
 			literals.Add("event", 27);
-			literals.Add("unless", 65);
-			literals.Add("super", 58);
-			literals.Add("set", 56);
-			literals.Add("transient", 62);
+			literals.Add("unless", 66);
+			literals.Add("super", 59);
+			literals.Add("set", 57);
+			literals.Add("transient", 63);
 			literals.Add("constructor", 19);
-			literals.Add("interface", 36);
-			literals.Add("of", 44);
-			literals.Add("is", 38);
-			literals.Add("internal", 37);
-			literals.Add("final", 29);
-			literals.Add("yield", 68);
-			literals.Add("or", 45);
+			literals.Add("interface", 37);
+			literals.Add("of", 45);
+			literals.Add("is", 39);
+			literals.Add("internal", 38);
+			literals.Add("final", 30);
+			literals.Add("yield", 69);
+			literals.Add("or", 46);
 			literals.Add("destructor", 21);
-			literals.Add("if", 40);
-			literals.Add("override", 46);
+			literals.Add("if", 41);
+			literals.Add("override", 47);
 			literals.Add("as", 12);
-			literals.Add("try", 61);
-			literals.Add("goto", 34);
+			literals.Add("try", 62);
+			literals.Add("goto", 35);
 			literals.Add("enum", 26);
-			literals.Add("isa", 39);
-			literals.Add("for", 31);
+			literals.Add("isa", 40);
+			literals.Add("for", 32);
 			literals.Add("char", 17);
-			literals.Add("private", 52);
-			literals.Add("false", 32);
-			literals.Add("static", 59);
+			literals.Add("private", 53);
+			literals.Add("false", 33);
+			literals.Add("static", 60);
 			literals.Add("abstract", 10);
-			literals.Add("partial", 49);
+			literals.Add("partial", 50);
 			literals.Add("callable", 15);
-			literals.Add("get", 33);
+			literals.Add("get", 34);
 			literals.Add("continue", 14);
 			literals.Add("cast", 16);
-			literals.Add("struct", 60);
+			literals.Add("struct", 61);
 			literals.Add("else", 24);
-			literals.Add("import", 35);
+			literals.Add("import", 36);
 			literals.Add("elif", 23);
-			literals.Add("in", 41);
-			literals.Add("self", 57);
+			literals.Add("in", 42);
+			literals.Add("self", 58);
 			literals.Add("ensure", 25);
-			literals.Add("true", 63);
-			literals.Add("virtual", 66);
+			literals.Add("true", 64);
+			literals.Add("virtual", 67);
 		}
 		
 		override public IToken nextToken()			//throws TokenStreamException
@@ -622,11 +624,11 @@ tryAgain:
 				}
 				else
 				{
-					goto _loop585_breakloop;
+					goto _loop607_breakloop;
 				}
 				
 			}
-_loop585_breakloop:			;
+_loop607_breakloop:			;
 		}    // ( ... )*
 		_ttype = testLiteralsTable(_ttype);
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -814,7 +816,7 @@ _loop585_breakloop:			;
 			{
 				match("0x");
 				{ // ( ... )+
-					int _cnt590=0;
+					int _cnt612=0;
 					for (;;)
 					{
 						if ((tokenSet_2_.member(cached_LA1)))
@@ -823,12 +825,12 @@ _loop585_breakloop:			;
 						}
 						else
 						{
-							if (_cnt590 >= 1) { goto _loop590_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt612 >= 1) { goto _loop612_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt590++;
+						_cnt612++;
 					}
-_loop590_breakloop:					;
+_loop612_breakloop:					;
 				}    // ( ... )+
 			}
 			{
@@ -1218,11 +1220,11 @@ _loop590_breakloop:					;
 				}
 				default:
 				{
-					goto _loop748_breakloop;
+					goto _loop770_breakloop;
 				}
 				 }
 			}
-_loop748_breakloop:			;
+_loop770_breakloop:			;
 		}    // ( ... )*
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1238,7 +1240,7 @@ _loop748_breakloop:			;
 		_ttype = REVERSE_DIGIT_GROUP;
 		
 		{ // ( ... )+
-			int _cnt752=0;
+			int _cnt774=0;
 			for (;;)
 			{
 				if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && ((cached_LA2 >= '0' && cached_LA2 <= '9')) && ((LA(3) >= '0' && LA(3) <= '9')))
@@ -1264,12 +1266,12 @@ _loop748_breakloop:			;
 				}
 				else
 				{
-					if (_cnt752 >= 1) { goto _loop752_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt774 >= 1) { goto _loop774_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt752++;
+				_cnt774++;
 			}
-_loop752_breakloop:			;
+_loop774_breakloop:			;
 		}    // ( ... )+
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1594,11 +1596,11 @@ _loop752_breakloop:			;
 			EnterSkipWhitespaceRegion();
 		}
 		{
-			bool synPredMatched634 = false;
+			bool synPredMatched656 = false;
 			if (((cached_LA1=='a')))
 			{
-				int _m634 = mark();
-				synPredMatched634 = true;
+				int _m656 = mark();
+				synPredMatched656 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1607,12 +1609,12 @@ _loop752_breakloop:			;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched634 = false;
+					synPredMatched656 = false;
 				}
-				rewind(_m634);
+				rewind(_m656);
 				inputState.guessing--;
 			}
-			if ( synPredMatched634 )
+			if ( synPredMatched656 )
 			{
 				match("assembly:");
 				if (0==inputState.guessing)
@@ -1874,11 +1876,11 @@ _loop752_breakloop:			;
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = DIVISION;
 		
-		bool synPredMatched655 = false;
+		bool synPredMatched677 = false;
 		if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 		{
-			int _m655 = mark();
-			synPredMatched655 = true;
+			int _m677 = mark();
+			synPredMatched677 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -1887,12 +1889,12 @@ _loop752_breakloop:			;
 			}
 			catch (RecognitionException)
 			{
-				synPredMatched655 = false;
+				synPredMatched677 = false;
 			}
-			rewind(_m655);
+			rewind(_m677);
 			inputState.guessing--;
 		}
-		if ( synPredMatched655 )
+		if ( synPredMatched677 )
 		{
 			mML_COMMENT(false);
 			if (0==inputState.guessing)
@@ -1901,11 +1903,11 @@ _loop752_breakloop:			;
 			}
 		}
 		else {
-			bool synPredMatched657 = false;
+			bool synPredMatched679 = false;
 			if (((cached_LA1=='/') && (tokenSet_3_.member(cached_LA2)) && (tokenSet_4_.member(LA(3)))))
 			{
-				int _m657 = mark();
-				synPredMatched657 = true;
+				int _m679 = mark();
+				synPredMatched679 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1914,12 +1916,12 @@ _loop752_breakloop:			;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched657 = false;
+					synPredMatched679 = false;
 				}
-				rewind(_m657);
+				rewind(_m679);
 				inputState.guessing--;
 			}
-			if ( synPredMatched657 )
+			if ( synPredMatched679 )
 			{
 				mRE_LITERAL(false);
 				if (0==inputState.guessing)
@@ -1947,11 +1949,11 @@ _loop752_breakloop:			;
 									}
 									else
 									{
-										goto _loop662_breakloop;
+										goto _loop684_breakloop;
 									}
 									
 								}
-_loop662_breakloop:								;
+_loop684_breakloop:								;
 							}    // ( ... )*
 							if (0==inputState.guessing)
 							{
@@ -2004,11 +2006,11 @@ _loop662_breakloop:								;
 					match('*');
 				}
 				else {
-					bool synPredMatched703 = false;
+					bool synPredMatched725 = false;
 					if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m703 = mark();
-						synPredMatched703 = true;
+						int _m725 = mark();
+						synPredMatched725 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -2017,12 +2019,12 @@ _loop662_breakloop:								;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched703 = false;
+							synPredMatched725 = false;
 						}
-						rewind(_m703);
+						rewind(_m725);
 						inputState.guessing--;
 					}
-					if ( synPredMatched703 )
+					if ( synPredMatched725 )
 					{
 						mML_COMMENT(false);
 					}
@@ -2036,11 +2038,11 @@ _loop662_breakloop:								;
 					}
 					else
 					{
-						goto _loop705_breakloop;
+						goto _loop727_breakloop;
 					}
 					}
 				}
-_loop705_breakloop:				;
+_loop727_breakloop:				;
 			}    // ( ... )*
 			match("*/");
 			if (0==inputState.guessing)
@@ -2062,7 +2064,7 @@ _loop705_breakloop:				;
 		
 		match('/');
 		{ // ( ... )+
-			int _cnt734=0;
+			int _cnt756=0;
 			for (;;)
 			{
 				if ((tokenSet_3_.member(cached_LA1)))
@@ -2071,12 +2073,12 @@ _loop705_breakloop:				;
 				}
 				else
 				{
-					if (_cnt734 >= 1) { goto _loop734_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt756 >= 1) { goto _loop756_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt734++;
+				_cnt756++;
 			}
-_loop734_breakloop:			;
+_loop756_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -2295,12 +2297,12 @@ _loop734_breakloop:			;
 			for (;;)
 			{
 				// nongreedy exit test
-				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop683_breakloop;
-				bool synPredMatched679 = false;
+				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop705_breakloop;
+				bool synPredMatched701 = false;
 				if (((cached_LA1=='$') && (cached_LA2=='{') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 				{
-					int _m679 = mark();
-					synPredMatched679 = true;
+					int _m701 = mark();
+					synPredMatched701 = true;
 					inputState.guessing++;
 					try {
 						{
@@ -2309,12 +2311,12 @@ _loop734_breakloop:			;
 					}
 					catch (RecognitionException)
 					{
-						synPredMatched679 = false;
+						synPredMatched701 = false;
 					}
-					rewind(_m679);
+					rewind(_m701);
 					inputState.guessing--;
 				}
-				if ( synPredMatched679 )
+				if ( synPredMatched701 )
 				{
 					if (0==inputState.guessing)
 					{
@@ -2326,11 +2328,11 @@ _loop734_breakloop:			;
 					mESCAPED_EXPRESSION(false);
 				}
 				else {
-					bool synPredMatched681 = false;
+					bool synPredMatched703 = false;
 					if (((cached_LA1=='\\') && (cached_LA2=='$') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m681 = mark();
-						synPredMatched681 = true;
+						int _m703 = mark();
+						synPredMatched703 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -2339,12 +2341,12 @@ _loop734_breakloop:			;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched681 = false;
+							synPredMatched703 = false;
 						}
-						rewind(_m681);
+						rewind(_m703);
 						inputState.guessing--;
 					}
-					if ( synPredMatched681 )
+					if ( synPredMatched703 )
 					{
 						_saveIndex = text.Length;
 						match('\\');
@@ -2361,11 +2363,11 @@ _loop734_breakloop:			;
 					}
 					else
 					{
-						goto _loop683_breakloop;
+						goto _loop705_breakloop;
 					}
 					}
 				}
-_loop683_breakloop:				;
+_loop705_breakloop:				;
 			}    // ( ... )*
 			_saveIndex = text.Length;
 			match("\"\"\"");
@@ -2433,11 +2435,11 @@ _loop683_breakloop:				;
 					{    // ( ... )*
 						for (;;)
 						{
-							bool synPredMatched689 = false;
+							bool synPredMatched711 = false;
 							if (((cached_LA1=='$') && (cached_LA2=='{') && (tokenSet_5_.member(LA(3)))))
 							{
-								int _m689 = mark();
-								synPredMatched689 = true;
+								int _m711 = mark();
+								synPredMatched711 = true;
 								inputState.guessing++;
 								try {
 									{
@@ -2446,12 +2448,12 @@ _loop683_breakloop:				;
 								}
 								catch (RecognitionException)
 								{
-									synPredMatched689 = false;
+									synPredMatched711 = false;
 								}
-								rewind(_m689);
+								rewind(_m711);
 								inputState.guessing--;
 							}
-							if ( synPredMatched689 )
+							if ( synPredMatched711 )
 							{
 								if (0==inputState.guessing)
 								{
@@ -2472,11 +2474,11 @@ _loop683_breakloop:				;
 							}
 							else
 							{
-								goto _loop691_breakloop;
+								goto _loop713_breakloop;
 							}
 							
 						}
-_loop691_breakloop:						;
+_loop713_breakloop:						;
 					}    // ( ... )*
 					_saveIndex = text.Length;
 					match('"');
@@ -2575,11 +2577,11 @@ _loop691_breakloop:						;
 				}
 				else
 				{
-					goto _loop695_breakloop;
+					goto _loop717_breakloop;
 				}
 				
 			}
-_loop695_breakloop:			;
+_loop717_breakloop:			;
 		}    // ( ... )*
 		_saveIndex = text.Length;
 		match('\'');
@@ -2647,11 +2649,11 @@ _loop695_breakloop:			;
 				}
 				else
 				{
-					goto _loop699_breakloop;
+					goto _loop721_breakloop;
 				}
 				
 			}
-_loop699_breakloop:			;
+_loop721_breakloop:			;
 		}    // ( ... )*
 		if (0==inputState.guessing)
 		{
@@ -2671,7 +2673,7 @@ _loop699_breakloop:			;
 		_ttype = WS;
 		
 		{ // ( ... )+
-			int _cnt708=0;
+			int _cnt730=0;
 			for (;;)
 			{
 				switch ( cached_LA1 )
@@ -2698,12 +2700,12 @@ _loop699_breakloop:			;
 				}
 				default:
 				{
-					if (_cnt708 >= 1) { goto _loop708_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt730 >= 1) { goto _loop730_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				break; }
-				_cnt708++;
+				_cnt730++;
 			}
-_loop708_breakloop:			;
+_loop730_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -2747,7 +2749,7 @@ _loop708_breakloop:			;
 		text.Length = _saveIndex;
 		match('/');
 		{ // ( ... )+
-			int _cnt712=0;
+			int _cnt734=0;
 			for (;;)
 			{
 				if ((tokenSet_9_.member(cached_LA1)))
@@ -2756,12 +2758,12 @@ _loop708_breakloop:			;
 				}
 				else
 				{
-					if (_cnt712 >= 1) { goto _loop712_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt734 >= 1) { goto _loop734_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt712++;
+				_cnt734++;
 			}
-_loop712_breakloop:			;
+_loop734_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (0==inputState.guessing)
@@ -3124,7 +3126,7 @@ _loop712_breakloop:			;
 			case '8':  case '9':
 			{
 				{ // ( ... )+
-					int _cnt742=0;
+					int _cnt764=0;
 					for (;;)
 					{
 						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_5_.member(cached_LA2)) && (true))
@@ -3133,12 +3135,12 @@ _loop712_breakloop:			;
 						}
 						else
 						{
-							if (_cnt742 >= 1) { goto _loop742_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt764 >= 1) { goto _loop764_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt742++;
+						_cnt764++;
 					}
-_loop742_breakloop:					;
+_loop764_breakloop:					;
 				}    // ( ... )+
 				break;
 			}
