@@ -86,110 +86,111 @@ namespace Boo.Lang.Parser
 		public const int ENUM = 24;
 		public const int EVENT = 25;
 		public const int EXCEPT = 26;
-		public const int FINAL = 27;
-		public const int FROM = 28;
-		public const int FOR = 29;
-		public const int FALSE = 30;
-		public const int GET = 31;
-		public const int GOTO = 32;
-		public const int IMPORT = 33;
-		public const int INTERFACE = 34;
-		public const int INTERNAL = 35;
-		public const int IS = 36;
-		public const int ISA = 37;
-		public const int IF = 38;
-		public const int IN = 39;
-		public const int NOT = 40;
-		public const int NULL = 41;
-		public const int OF = 42;
-		public const int OR = 43;
-		public const int OVERRIDE = 44;
-		public const int NAMESPACE = 45;
-		public const int PUBLIC = 46;
-		public const int PROTECTED = 47;
-		public const int PRIVATE = 48;
-		public const int RAISE = 49;
-		public const int REF = 50;
-		public const int RETURN = 51;
-		public const int SET = 52;
-		public const int SELF = 53;
-		public const int SUPER = 54;
-		public const int STATIC = 55;
-		public const int STRUCT = 56;
-		public const int TRY = 57;
-		public const int TRANSIENT = 58;
-		public const int TRUE = 59;
-		public const int TYPEOF = 60;
-		public const int UNLESS = 61;
-		public const int VIRTUAL = 62;
-		public const int PARTIAL = 63;
-		public const int WHILE = 64;
-		public const int YIELD = 65;
-		public const int TRIPLE_QUOTED_STRING = 66;
-		public const int EOS = 67;
-		public const int NEWLINE = 68;
-		public const int DOUBLE_QUOTED_STRING = 69;
-		public const int SINGLE_QUOTED_STRING = 70;
-		public const int ID = 71;
-		public const int LBRACK = 72;
-		public const int RBRACK = 73;
-		public const int LPAREN = 74;
-		public const int RPAREN = 75;
-		public const int ASSIGN = 76;
-		public const int SUBTRACT = 77;
-		public const int COMMA = 78;
-		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 79;
-		public const int DOT = 80;
-		public const int COLON = 81;
-		public const int MULTIPLY = 82;
-		public const int SPLICE_BEGIN = 83;
-		public const int BITWISE_OR = 84;
-		public const int LBRACE = 85;
-		public const int RBRACE = 86;
-		public const int QQ_BEGIN = 87;
-		public const int QQ_END = 88;
-		public const int INPLACE_BITWISE_OR = 89;
-		public const int INPLACE_BITWISE_AND = 90;
-		public const int INPLACE_SHIFT_LEFT = 91;
-		public const int INPLACE_SHIFT_RIGHT = 92;
-		public const int CMP_OPERATOR = 93;
-		public const int GREATER_THAN = 94;
-		public const int LESS_THAN = 95;
-		public const int ADD = 96;
-		public const int EXCLUSIVE_OR = 97;
-		public const int DIVISION = 98;
-		public const int MODULUS = 99;
-		public const int BITWISE_AND = 100;
-		public const int SHIFT_LEFT = 101;
-		public const int SHIFT_RIGHT = 102;
-		public const int EXPONENTIATION = 103;
-		public const int INCREMENT = 104;
-		public const int DECREMENT = 105;
-		public const int ONES_COMPLEMENT = 106;
-		public const int INT = 107;
-		public const int LONG = 108;
-		public const int RE_LITERAL = 109;
-		public const int DOUBLE = 110;
-		public const int FLOAT = 111;
-		public const int TIMESPAN = 112;
-		public const int LINE_CONTINUATION = 113;
-		public const int SL_COMMENT = 114;
-		public const int ML_COMMENT = 115;
-		public const int WS = 116;
-		public const int X_RE_LITERAL = 117;
-		public const int ESCAPED_EXPRESSION = 118;
-		public const int DQS_ESC = 119;
-		public const int SQS_ESC = 120;
-		public const int SESC = 121;
-		public const int RE_CHAR = 122;
-		public const int X_RE_CHAR = 123;
-		public const int RE_ESC = 124;
-		public const int DIGIT_GROUP = 125;
-		public const int REVERSE_DIGIT_GROUP = 126;
-		public const int ID_PREFIX = 127;
-		public const int ID_LETTER = 128;
-		public const int DIGIT = 129;
-		public const int HEXDIGIT = 130;
+		public const int FAILURE = 27;
+		public const int FINAL = 28;
+		public const int FROM = 29;
+		public const int FOR = 30;
+		public const int FALSE = 31;
+		public const int GET = 32;
+		public const int GOTO = 33;
+		public const int IMPORT = 34;
+		public const int INTERFACE = 35;
+		public const int INTERNAL = 36;
+		public const int IS = 37;
+		public const int ISA = 38;
+		public const int IF = 39;
+		public const int IN = 40;
+		public const int NOT = 41;
+		public const int NULL = 42;
+		public const int OF = 43;
+		public const int OR = 44;
+		public const int OVERRIDE = 45;
+		public const int NAMESPACE = 46;
+		public const int PUBLIC = 47;
+		public const int PROTECTED = 48;
+		public const int PRIVATE = 49;
+		public const int RAISE = 50;
+		public const int REF = 51;
+		public const int RETURN = 52;
+		public const int SET = 53;
+		public const int SELF = 54;
+		public const int SUPER = 55;
+		public const int STATIC = 56;
+		public const int STRUCT = 57;
+		public const int TRY = 58;
+		public const int TRANSIENT = 59;
+		public const int TRUE = 60;
+		public const int TYPEOF = 61;
+		public const int UNLESS = 62;
+		public const int VIRTUAL = 63;
+		public const int PARTIAL = 64;
+		public const int WHILE = 65;
+		public const int YIELD = 66;
+		public const int TRIPLE_QUOTED_STRING = 67;
+		public const int EOS = 68;
+		public const int NEWLINE = 69;
+		public const int DOUBLE_QUOTED_STRING = 70;
+		public const int SINGLE_QUOTED_STRING = 71;
+		public const int ID = 72;
+		public const int LBRACK = 73;
+		public const int RBRACK = 74;
+		public const int LPAREN = 75;
+		public const int RPAREN = 76;
+		public const int ASSIGN = 77;
+		public const int SUBTRACT = 78;
+		public const int COMMA = 79;
+		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 80;
+		public const int DOT = 81;
+		public const int COLON = 82;
+		public const int MULTIPLY = 83;
+		public const int SPLICE_BEGIN = 84;
+		public const int BITWISE_OR = 85;
+		public const int LBRACE = 86;
+		public const int RBRACE = 87;
+		public const int QQ_BEGIN = 88;
+		public const int QQ_END = 89;
+		public const int INPLACE_BITWISE_OR = 90;
+		public const int INPLACE_BITWISE_AND = 91;
+		public const int INPLACE_SHIFT_LEFT = 92;
+		public const int INPLACE_SHIFT_RIGHT = 93;
+		public const int CMP_OPERATOR = 94;
+		public const int GREATER_THAN = 95;
+		public const int LESS_THAN = 96;
+		public const int ADD = 97;
+		public const int EXCLUSIVE_OR = 98;
+		public const int DIVISION = 99;
+		public const int MODULUS = 100;
+		public const int BITWISE_AND = 101;
+		public const int SHIFT_LEFT = 102;
+		public const int SHIFT_RIGHT = 103;
+		public const int EXPONENTIATION = 104;
+		public const int INCREMENT = 105;
+		public const int DECREMENT = 106;
+		public const int ONES_COMPLEMENT = 107;
+		public const int INT = 108;
+		public const int LONG = 109;
+		public const int RE_LITERAL = 110;
+		public const int DOUBLE = 111;
+		public const int FLOAT = 112;
+		public const int TIMESPAN = 113;
+		public const int LINE_CONTINUATION = 114;
+		public const int SL_COMMENT = 115;
+		public const int ML_COMMENT = 116;
+		public const int WS = 117;
+		public const int X_RE_LITERAL = 118;
+		public const int ESCAPED_EXPRESSION = 119;
+		public const int DQS_ESC = 120;
+		public const int SQS_ESC = 121;
+		public const int SESC = 122;
+		public const int RE_CHAR = 123;
+		public const int X_RE_CHAR = 124;
+		public const int RE_ESC = 125;
+		public const int DIGIT_GROUP = 126;
+		public const int REVERSE_DIGIT_GROUP = 127;
+		public const int ID_PREFIX = 128;
+		public const int ID_LETTER = 129;
+		public const int DIGIT = 130;
+		public const int HEXDIGIT = 131;
 		
 		
 	
@@ -223,65 +224,66 @@ namespace Boo.Lang.Parser
 			caseSensitiveLiterals = true;
 			setCaseSensitive(true);
 			literals = new Hashtable(100, (float) 0.4, null, Comparer.Default);
-			literals.Add("public", 46);
-			literals.Add("namespace", 45);
+			literals.Add("public", 47);
+			literals.Add("namespace", 46);
 			literals.Add("break", 10);
-			literals.Add("while", 64);
+			literals.Add("while", 65);
 			literals.Add("end", 22);
-			literals.Add("raise", 49);
-			literals.Add("typeof", 60);
+			literals.Add("raise", 50);
+			literals.Add("typeof", 61);
 			literals.Add("and", 8);
-			literals.Add("not", 40);
-			literals.Add("return", 51);
-			literals.Add("from", 28);
-			literals.Add("null", 41);
+			literals.Add("failure", 27);
+			literals.Add("not", 41);
+			literals.Add("return", 52);
+			literals.Add("from", 29);
+			literals.Add("null", 42);
 			literals.Add("def", 17);
-			literals.Add("protected", 47);
-			literals.Add("ref", 50);
+			literals.Add("protected", 48);
+			literals.Add("ref", 51);
 			literals.Add("class", 15);
 			literals.Add("do", 19);
 			literals.Add("except", 26);
 			literals.Add("event", 25);
-			literals.Add("unless", 61);
-			literals.Add("super", 54);
-			literals.Add("set", 52);
-			literals.Add("transient", 58);
+			literals.Add("unless", 62);
+			literals.Add("super", 55);
+			literals.Add("set", 53);
+			literals.Add("transient", 59);
 			literals.Add("constructor", 16);
-			literals.Add("interface", 34);
-			literals.Add("of", 42);
-			literals.Add("is", 36);
-			literals.Add("internal", 35);
-			literals.Add("final", 27);
-			literals.Add("yield", 65);
-			literals.Add("or", 43);
+			literals.Add("interface", 35);
+			literals.Add("of", 43);
+			literals.Add("is", 37);
+			literals.Add("internal", 36);
+			literals.Add("final", 28);
+			literals.Add("yield", 66);
+			literals.Add("or", 44);
 			literals.Add("destructor", 18);
-			literals.Add("if", 38);
-			literals.Add("override", 44);
+			literals.Add("if", 39);
+			literals.Add("override", 45);
 			literals.Add("as", 9);
-			literals.Add("try", 57);
-			literals.Add("goto", 32);
+			literals.Add("try", 58);
+			literals.Add("goto", 33);
 			literals.Add("enum", 24);
-			literals.Add("isa", 37);
-			literals.Add("for", 29);
+			literals.Add("isa", 38);
+			literals.Add("for", 30);
 			literals.Add("char", 14);
-			literals.Add("private", 48);
-			literals.Add("false", 30);
-			literals.Add("static", 55);
+			literals.Add("private", 49);
+			literals.Add("false", 31);
+			literals.Add("static", 56);
 			literals.Add("abstract", 7);
-			literals.Add("partial", 63);
+			literals.Add("partial", 64);
 			literals.Add("callable", 12);
-			literals.Add("get", 31);
+			literals.Add("get", 32);
 			literals.Add("continue", 11);
 			literals.Add("cast", 13);
-			literals.Add("struct", 56);
+			literals.Add("struct", 57);
 			literals.Add("else", 21);
-			literals.Add("import", 33);
+			literals.Add("import", 34);
 			literals.Add("elif", 20);
-			literals.Add("in", 39);
-			literals.Add("self", 53);
+			literals.Add("in", 40);
+			literals.Add("self", 54);
 			literals.Add("ensure", 23);
-			literals.Add("true", 59);
-			literals.Add("virtual", 62);
+			literals.Add("true", 60);
+			literals.Add("virtual", 63);
 		}
 		
 		override public IToken nextToken()			//throws TokenStreamException
