@@ -88,110 +88,111 @@ using Boo.Lang.Parser.Util;
 		public const int ENUM = 24;
 		public const int EVENT = 25;
 		public const int EXCEPT = 26;
-		public const int FINAL = 27;
-		public const int FROM = 28;
-		public const int FOR = 29;
-		public const int FALSE = 30;
-		public const int GET = 31;
-		public const int GOTO = 32;
-		public const int IMPORT = 33;
-		public const int INTERFACE = 34;
-		public const int INTERNAL = 35;
-		public const int IS = 36;
-		public const int ISA = 37;
-		public const int IF = 38;
-		public const int IN = 39;
-		public const int NOT = 40;
-		public const int NULL = 41;
-		public const int OF = 42;
-		public const int OR = 43;
-		public const int OVERRIDE = 44;
-		public const int NAMESPACE = 45;
-		public const int PUBLIC = 46;
-		public const int PROTECTED = 47;
-		public const int PRIVATE = 48;
-		public const int RAISE = 49;
-		public const int REF = 50;
-		public const int RETURN = 51;
-		public const int SET = 52;
-		public const int SELF = 53;
-		public const int SUPER = 54;
-		public const int STATIC = 55;
-		public const int STRUCT = 56;
-		public const int TRY = 57;
-		public const int TRANSIENT = 58;
-		public const int TRUE = 59;
-		public const int TYPEOF = 60;
-		public const int UNLESS = 61;
-		public const int VIRTUAL = 62;
-		public const int PARTIAL = 63;
-		public const int WHILE = 64;
-		public const int YIELD = 65;
-		public const int TRIPLE_QUOTED_STRING = 66;
-		public const int EOS = 67;
-		public const int NEWLINE = 68;
-		public const int DOUBLE_QUOTED_STRING = 69;
-		public const int SINGLE_QUOTED_STRING = 70;
-		public const int ID = 71;
-		public const int LBRACK = 72;
-		public const int RBRACK = 73;
-		public const int LPAREN = 74;
-		public const int RPAREN = 75;
-		public const int ASSIGN = 76;
-		public const int SUBTRACT = 77;
-		public const int COMMA = 78;
-		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 79;
-		public const int DOT = 80;
-		public const int COLON = 81;
-		public const int MULTIPLY = 82;
-		public const int SPLICE_BEGIN = 83;
-		public const int BITWISE_OR = 84;
-		public const int LBRACE = 85;
-		public const int RBRACE = 86;
-		public const int QQ_BEGIN = 87;
-		public const int QQ_END = 88;
-		public const int INPLACE_BITWISE_OR = 89;
-		public const int INPLACE_BITWISE_AND = 90;
-		public const int INPLACE_SHIFT_LEFT = 91;
-		public const int INPLACE_SHIFT_RIGHT = 92;
-		public const int CMP_OPERATOR = 93;
-		public const int GREATER_THAN = 94;
-		public const int LESS_THAN = 95;
-		public const int ADD = 96;
-		public const int EXCLUSIVE_OR = 97;
-		public const int DIVISION = 98;
-		public const int MODULUS = 99;
-		public const int BITWISE_AND = 100;
-		public const int SHIFT_LEFT = 101;
-		public const int SHIFT_RIGHT = 102;
-		public const int EXPONENTIATION = 103;
-		public const int INCREMENT = 104;
-		public const int DECREMENT = 105;
-		public const int ONES_COMPLEMENT = 106;
-		public const int INT = 107;
-		public const int LONG = 108;
-		public const int RE_LITERAL = 109;
-		public const int DOUBLE = 110;
-		public const int FLOAT = 111;
-		public const int TIMESPAN = 112;
-		public const int LINE_CONTINUATION = 113;
-		public const int SL_COMMENT = 114;
-		public const int ML_COMMENT = 115;
-		public const int WS = 116;
-		public const int X_RE_LITERAL = 117;
-		public const int ESCAPED_EXPRESSION = 118;
-		public const int DQS_ESC = 119;
-		public const int SQS_ESC = 120;
-		public const int SESC = 121;
-		public const int RE_CHAR = 122;
-		public const int X_RE_CHAR = 123;
-		public const int RE_ESC = 124;
-		public const int DIGIT_GROUP = 125;
-		public const int REVERSE_DIGIT_GROUP = 126;
-		public const int ID_PREFIX = 127;
-		public const int ID_LETTER = 128;
-		public const int DIGIT = 129;
-		public const int HEXDIGIT = 130;
+		public const int FAILURE = 27;
+		public const int FINAL = 28;
+		public const int FROM = 29;
+		public const int FOR = 30;
+		public const int FALSE = 31;
+		public const int GET = 32;
+		public const int GOTO = 33;
+		public const int IMPORT = 34;
+		public const int INTERFACE = 35;
+		public const int INTERNAL = 36;
+		public const int IS = 37;
+		public const int ISA = 38;
+		public const int IF = 39;
+		public const int IN = 40;
+		public const int NOT = 41;
+		public const int NULL = 42;
+		public const int OF = 43;
+		public const int OR = 44;
+		public const int OVERRIDE = 45;
+		public const int NAMESPACE = 46;
+		public const int PUBLIC = 47;
+		public const int PROTECTED = 48;
+		public const int PRIVATE = 49;
+		public const int RAISE = 50;
+		public const int REF = 51;
+		public const int RETURN = 52;
+		public const int SET = 53;
+		public const int SELF = 54;
+		public const int SUPER = 55;
+		public const int STATIC = 56;
+		public const int STRUCT = 57;
+		public const int TRY = 58;
+		public const int TRANSIENT = 59;
+		public const int TRUE = 60;
+		public const int TYPEOF = 61;
+		public const int UNLESS = 62;
+		public const int VIRTUAL = 63;
+		public const int PARTIAL = 64;
+		public const int WHILE = 65;
+		public const int YIELD = 66;
+		public const int TRIPLE_QUOTED_STRING = 67;
+		public const int EOS = 68;
+		public const int NEWLINE = 69;
+		public const int DOUBLE_QUOTED_STRING = 70;
+		public const int SINGLE_QUOTED_STRING = 71;
+		public const int ID = 72;
+		public const int LBRACK = 73;
+		public const int RBRACK = 74;
+		public const int LPAREN = 75;
+		public const int RPAREN = 76;
+		public const int ASSIGN = 77;
+		public const int SUBTRACT = 78;
+		public const int COMMA = 79;
+		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 80;
+		public const int DOT = 81;
+		public const int COLON = 82;
+		public const int MULTIPLY = 83;
+		public const int SPLICE_BEGIN = 84;
+		public const int BITWISE_OR = 85;
+		public const int LBRACE = 86;
+		public const int RBRACE = 87;
+		public const int QQ_BEGIN = 88;
+		public const int QQ_END = 89;
+		public const int INPLACE_BITWISE_OR = 90;
+		public const int INPLACE_BITWISE_AND = 91;
+		public const int INPLACE_SHIFT_LEFT = 92;
+		public const int INPLACE_SHIFT_RIGHT = 93;
+		public const int CMP_OPERATOR = 94;
+		public const int GREATER_THAN = 95;
+		public const int LESS_THAN = 96;
+		public const int ADD = 97;
+		public const int EXCLUSIVE_OR = 98;
+		public const int DIVISION = 99;
+		public const int MODULUS = 100;
+		public const int BITWISE_AND = 101;
+		public const int SHIFT_LEFT = 102;
+		public const int SHIFT_RIGHT = 103;
+		public const int EXPONENTIATION = 104;
+		public const int INCREMENT = 105;
+		public const int DECREMENT = 106;
+		public const int ONES_COMPLEMENT = 107;
+		public const int INT = 108;
+		public const int LONG = 109;
+		public const int RE_LITERAL = 110;
+		public const int DOUBLE = 111;
+		public const int FLOAT = 112;
+		public const int TIMESPAN = 113;
+		public const int LINE_CONTINUATION = 114;
+		public const int SL_COMMENT = 115;
+		public const int ML_COMMENT = 116;
+		public const int WS = 117;
+		public const int X_RE_LITERAL = 118;
+		public const int ESCAPED_EXPRESSION = 119;
+		public const int DQS_ESC = 120;
+		public const int SQS_ESC = 121;
+		public const int SESC = 122;
+		public const int RE_CHAR = 123;
+		public const int X_RE_CHAR = 124;
+		public const int RE_ESC = 125;
+		public const int DIGIT_GROUP = 126;
+		public const int REVERSE_DIGIT_GROUP = 127;
+		public const int ID_PREFIX = 128;
+		public const int ID_LETTER = 129;
+		public const int DIGIT = 130;
+		public const int HEXDIGIT = 131;
 		
 		
 	protected int _skipWhitespaceRegion = 0;
@@ -273,65 +274,66 @@ using Boo.Lang.Parser.Util;
 			caseSensitiveLiterals = true;
 			setCaseSensitive(true);
 			literals = new Hashtable(100, (float) 0.4, null, Comparer.Default);
-			literals.Add("public", 46);
-			literals.Add("namespace", 45);
+			literals.Add("public", 47);
+			literals.Add("namespace", 46);
 			literals.Add("break", 10);
-			literals.Add("while", 64);
+			literals.Add("while", 65);
 			literals.Add("end", 22);
-			literals.Add("raise", 49);
-			literals.Add("typeof", 60);
+			literals.Add("raise", 50);
+			literals.Add("typeof", 61);
 			literals.Add("and", 8);
-			literals.Add("not", 40);
-			literals.Add("return", 51);
-			literals.Add("from", 28);
-			literals.Add("null", 41);
+			literals.Add("failure", 27);
+			literals.Add("not", 41);
+			literals.Add("return", 52);
+			literals.Add("from", 29);
+			literals.Add("null", 42);
 			literals.Add("def", 17);
-			literals.Add("protected", 47);
-			literals.Add("ref", 50);
+			literals.Add("protected", 48);
+			literals.Add("ref", 51);
 			literals.Add("class", 15);
 			literals.Add("do", 19);
 			literals.Add("except", 26);
 			literals.Add("event", 25);
-			literals.Add("unless", 61);
-			literals.Add("super", 54);
-			literals.Add("set", 52);
-			literals.Add("transient", 58);
+			literals.Add("unless", 62);
+			literals.Add("super", 55);
+			literals.Add("set", 53);
+			literals.Add("transient", 59);
 			literals.Add("constructor", 16);
-			literals.Add("interface", 34);
-			literals.Add("of", 42);
-			literals.Add("is", 36);
-			literals.Add("internal", 35);
-			literals.Add("final", 27);
-			literals.Add("yield", 65);
-			literals.Add("or", 43);
+			literals.Add("interface", 35);
+			literals.Add("of", 43);
+			literals.Add("is", 37);
+			literals.Add("internal", 36);
+			literals.Add("final", 28);
+			literals.Add("yield", 66);
+			literals.Add("or", 44);
 			literals.Add("destructor", 18);
-			literals.Add("if", 38);
-			literals.Add("override", 44);
+			literals.Add("if", 39);
+			literals.Add("override", 45);
 			literals.Add("as", 9);
-			literals.Add("try", 57);
-			literals.Add("goto", 32);
+			literals.Add("try", 58);
+			literals.Add("goto", 33);
 			literals.Add("enum", 24);
-			literals.Add("isa", 37);
-			literals.Add("for", 29);
+			literals.Add("isa", 38);
+			literals.Add("for", 30);
 			literals.Add("char", 14);
-			literals.Add("private", 48);
-			literals.Add("false", 30);
-			literals.Add("static", 55);
+			literals.Add("private", 49);
+			literals.Add("false", 31);
+			literals.Add("static", 56);
 			literals.Add("abstract", 7);
-			literals.Add("partial", 63);
+			literals.Add("partial", 64);
 			literals.Add("callable", 12);
-			literals.Add("get", 31);
+			literals.Add("get", 32);
 			literals.Add("continue", 11);
 			literals.Add("cast", 13);
-			literals.Add("struct", 56);
+			literals.Add("struct", 57);
 			literals.Add("else", 21);
-			literals.Add("import", 33);
+			literals.Add("import", 34);
 			literals.Add("elif", 20);
-			literals.Add("in", 39);
-			literals.Add("self", 53);
+			literals.Add("in", 40);
+			literals.Add("self", 54);
 			literals.Add("ensure", 23);
-			literals.Add("true", 59);
-			literals.Add("virtual", 62);
+			literals.Add("true", 60);
+			literals.Add("virtual", 63);
 		}
 		
 		override public IToken nextToken()			//throws TokenStreamException
@@ -624,11 +626,11 @@ tryAgain:
 				}
 				else
 				{
-					goto _loop542_breakloop;
+					goto _loop553_breakloop;
 				}
 				
 			}
-_loop542_breakloop:			;
+_loop553_breakloop:			;
 		}    // ( ... )*
 		_ttype = testLiteralsTable(_ttype);
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -765,7 +767,7 @@ _loop542_breakloop:			;
 		_ttype = NEWLINE;
 		
 		{ // ( ... )+
-			int _cnt675=0;
+			int _cnt686=0;
 			for (;;)
 			{
 				if ((cached_LA1=='\n'||cached_LA1=='\r') && (true) && (true))
@@ -807,12 +809,12 @@ _loop542_breakloop:			;
 				}
 				else
 				{
-					if (_cnt675 >= 1) { goto _loop675_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt686 >= 1) { goto _loop686_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt675++;
+				_cnt686++;
 			}
-_loop675_breakloop:			;
+_loop686_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -841,7 +843,7 @@ _loop675_breakloop:			;
 			{
 				match("0x");
 				{ // ( ... )+
-					int _cnt547=0;
+					int _cnt558=0;
 					for (;;)
 					{
 						if ((tokenSet_2_.member(cached_LA1)))
@@ -850,12 +852,12 @@ _loop675_breakloop:			;
 						}
 						else
 						{
-							if (_cnt547 >= 1) { goto _loop547_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt558 >= 1) { goto _loop558_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt547++;
+						_cnt558++;
 					}
-_loop547_breakloop:					;
+_loop558_breakloop:					;
 				}    // ( ... )+
 			}
 			{
@@ -1245,11 +1247,11 @@ _loop547_breakloop:					;
 				}
 				default:
 				{
-					goto _loop707_breakloop;
+					goto _loop718_breakloop;
 				}
 				 }
 			}
-_loop707_breakloop:			;
+_loop718_breakloop:			;
 		}    // ( ... )*
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1265,7 +1267,7 @@ _loop707_breakloop:			;
 		_ttype = REVERSE_DIGIT_GROUP;
 		
 		{ // ( ... )+
-			int _cnt711=0;
+			int _cnt722=0;
 			for (;;)
 			{
 				if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && ((cached_LA2 >= '0' && cached_LA2 <= '9')) && ((LA(3) >= '0' && LA(3) <= '9')))
@@ -1291,12 +1293,12 @@ _loop707_breakloop:			;
 				}
 				else
 				{
-					if (_cnt711 >= 1) { goto _loop711_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt722 >= 1) { goto _loop722_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt711++;
+				_cnt722++;
 			}
-_loop711_breakloop:			;
+_loop722_breakloop:			;
 		}    // ( ... )+
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1621,11 +1623,11 @@ _loop711_breakloop:			;
 			EnterSkipWhitespaceRegion();
 		}
 		{
-			bool synPredMatched591 = false;
+			bool synPredMatched602 = false;
 			if (((cached_LA1=='a')))
 			{
-				int _m591 = mark();
-				synPredMatched591 = true;
+				int _m602 = mark();
+				synPredMatched602 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1634,12 +1636,12 @@ _loop711_breakloop:			;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched591 = false;
+					synPredMatched602 = false;
 				}
-				rewind(_m591);
+				rewind(_m602);
 				inputState.guessing--;
 			}
-			if ( synPredMatched591 )
+			if ( synPredMatched602 )
 			{
 				match("assembly:");
 				if (0==inputState.guessing)
@@ -1901,11 +1903,11 @@ _loop711_breakloop:			;
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = DIVISION;
 		
-		bool synPredMatched612 = false;
+		bool synPredMatched623 = false;
 		if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 		{
-			int _m612 = mark();
-			synPredMatched612 = true;
+			int _m623 = mark();
+			synPredMatched623 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -1914,12 +1916,12 @@ _loop711_breakloop:			;
 			}
 			catch (RecognitionException)
 			{
-				synPredMatched612 = false;
+				synPredMatched623 = false;
 			}
-			rewind(_m612);
+			rewind(_m623);
 			inputState.guessing--;
 		}
-		if ( synPredMatched612 )
+		if ( synPredMatched623 )
 		{
 			mML_COMMENT(false);
 			if (0==inputState.guessing)
@@ -1928,11 +1930,11 @@ _loop711_breakloop:			;
 			}
 		}
 		else {
-			bool synPredMatched614 = false;
+			bool synPredMatched625 = false;
 			if (((cached_LA1=='/') && (tokenSet_3_.member(cached_LA2)) && (tokenSet_4_.member(LA(3)))))
 			{
-				int _m614 = mark();
-				synPredMatched614 = true;
+				int _m625 = mark();
+				synPredMatched625 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1941,12 +1943,12 @@ _loop711_breakloop:			;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched614 = false;
+					synPredMatched625 = false;
 				}
-				rewind(_m614);
+				rewind(_m625);
 				inputState.guessing--;
 			}
-			if ( synPredMatched614 )
+			if ( synPredMatched625 )
 			{
 				mRE_LITERAL(false);
 				if (0==inputState.guessing)
@@ -1974,11 +1976,11 @@ _loop711_breakloop:			;
 									}
 									else
 									{
-										goto _loop619_breakloop;
+										goto _loop630_breakloop;
 									}
 									
 								}
-_loop619_breakloop:								;
+_loop630_breakloop:								;
 							}    // ( ... )*
 							if (0==inputState.guessing)
 							{
@@ -2031,11 +2033,11 @@ _loop619_breakloop:								;
 					match('*');
 				}
 				else {
-					bool synPredMatched660 = false;
+					bool synPredMatched671 = false;
 					if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m660 = mark();
-						synPredMatched660 = true;
+						int _m671 = mark();
+						synPredMatched671 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -2044,12 +2046,12 @@ _loop619_breakloop:								;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched660 = false;
+							synPredMatched671 = false;
 						}
-						rewind(_m660);
+						rewind(_m671);
 						inputState.guessing--;
 					}
-					if ( synPredMatched660 )
+					if ( synPredMatched671 )
 					{
 						mML_COMMENT(false);
 					}
@@ -2063,11 +2065,11 @@ _loop619_breakloop:								;
 					}
 					else
 					{
-						goto _loop662_breakloop;
+						goto _loop673_breakloop;
 					}
 					}
 				}
-_loop662_breakloop:				;
+_loop673_breakloop:				;
 			}    // ( ... )*
 			match("*/");
 			if (0==inputState.guessing)
@@ -2089,7 +2091,7 @@ _loop662_breakloop:				;
 		
 		match('/');
 		{ // ( ... )+
-			int _cnt693=0;
+			int _cnt704=0;
 			for (;;)
 			{
 				if ((tokenSet_3_.member(cached_LA1)))
@@ -2098,12 +2100,12 @@ _loop662_breakloop:				;
 				}
 				else
 				{
-					if (_cnt693 >= 1) { goto _loop693_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt704 >= 1) { goto _loop704_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt693++;
+				_cnt704++;
 			}
-_loop693_breakloop:			;
+_loop704_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -2322,12 +2324,12 @@ _loop693_breakloop:			;
 			for (;;)
 			{
 				// nongreedy exit test
-				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop640_breakloop;
-				bool synPredMatched636 = false;
+				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop651_breakloop;
+				bool synPredMatched647 = false;
 				if (((cached_LA1=='$') && (cached_LA2=='{') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 				{
-					int _m636 = mark();
-					synPredMatched636 = true;
+					int _m647 = mark();
+					synPredMatched647 = true;
 					inputState.guessing++;
 					try {
 						{
@@ -2336,12 +2338,12 @@ _loop693_breakloop:			;
 					}
 					catch (RecognitionException)
 					{
-						synPredMatched636 = false;
+						synPredMatched647 = false;
 					}
-					rewind(_m636);
+					rewind(_m647);
 					inputState.guessing--;
 				}
-				if ( synPredMatched636 )
+				if ( synPredMatched647 )
 				{
 					if (0==inputState.guessing)
 					{
@@ -2353,11 +2355,11 @@ _loop693_breakloop:			;
 					mESCAPED_EXPRESSION(false);
 				}
 				else {
-					bool synPredMatched638 = false;
+					bool synPredMatched649 = false;
 					if (((cached_LA1=='\\') && (cached_LA2=='$') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m638 = mark();
-						synPredMatched638 = true;
+						int _m649 = mark();
+						synPredMatched649 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -2366,12 +2368,12 @@ _loop693_breakloop:			;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched638 = false;
+							synPredMatched649 = false;
 						}
-						rewind(_m638);
+						rewind(_m649);
 						inputState.guessing--;
 					}
-					if ( synPredMatched638 )
+					if ( synPredMatched649 )
 					{
 						_saveIndex = text.Length;
 						match('\\');
@@ -2388,11 +2390,11 @@ _loop693_breakloop:			;
 					}
 					else
 					{
-						goto _loop640_breakloop;
+						goto _loop651_breakloop;
 					}
 					}
 				}
-_loop640_breakloop:				;
+_loop651_breakloop:				;
 			}    // ( ... )*
 			_saveIndex = text.Length;
 			match("\"\"\"");
@@ -2460,11 +2462,11 @@ _loop640_breakloop:				;
 					{    // ( ... )*
 						for (;;)
 						{
-							bool synPredMatched646 = false;
+							bool synPredMatched657 = false;
 							if (((cached_LA1=='$') && (cached_LA2=='{') && (tokenSet_5_.member(LA(3)))))
 							{
-								int _m646 = mark();
-								synPredMatched646 = true;
+								int _m657 = mark();
+								synPredMatched657 = true;
 								inputState.guessing++;
 								try {
 									{
@@ -2473,12 +2475,12 @@ _loop640_breakloop:				;
 								}
 								catch (RecognitionException)
 								{
-									synPredMatched646 = false;
+									synPredMatched657 = false;
 								}
-								rewind(_m646);
+								rewind(_m657);
 								inputState.guessing--;
 							}
-							if ( synPredMatched646 )
+							if ( synPredMatched657 )
 							{
 								if (0==inputState.guessing)
 								{
@@ -2499,11 +2501,11 @@ _loop640_breakloop:				;
 							}
 							else
 							{
-								goto _loop648_breakloop;
+								goto _loop659_breakloop;
 							}
 							
 						}
-_loop648_breakloop:						;
+_loop659_breakloop:						;
 					}    // ( ... )*
 					_saveIndex = text.Length;
 					match('"');
@@ -2602,11 +2604,11 @@ _loop648_breakloop:						;
 				}
 				else
 				{
-					goto _loop652_breakloop;
+					goto _loop663_breakloop;
 				}
 				
 			}
-_loop652_breakloop:			;
+_loop663_breakloop:			;
 		}    // ( ... )*
 		_saveIndex = text.Length;
 		match('\'');
@@ -2674,11 +2676,11 @@ _loop652_breakloop:			;
 				}
 				else
 				{
-					goto _loop656_breakloop;
+					goto _loop667_breakloop;
 				}
 				
 			}
-_loop656_breakloop:			;
+_loop667_breakloop:			;
 		}    // ( ... )*
 		if (0==inputState.guessing)
 		{
@@ -2698,7 +2700,7 @@ _loop656_breakloop:			;
 		_ttype = WS;
 		
 		{ // ( ... )+
-			int _cnt665=0;
+			int _cnt676=0;
 			for (;;)
 			{
 				switch ( cached_LA1 )
@@ -2724,12 +2726,12 @@ _loop656_breakloop:			;
 				}
 				default:
 				{
-					if (_cnt665 >= 1) { goto _loop665_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt676 >= 1) { goto _loop676_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				break; }
-				_cnt665++;
+				_cnt676++;
 			}
-_loop665_breakloop:			;
+_loop676_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -2770,7 +2772,7 @@ _loop665_breakloop:			;
 		text.Length = _saveIndex;
 		match('/');
 		{ // ( ... )+
-			int _cnt669=0;
+			int _cnt680=0;
 			for (;;)
 			{
 				if ((tokenSet_9_.member(cached_LA1)))
@@ -2779,12 +2781,12 @@ _loop665_breakloop:			;
 				}
 				else
 				{
-					if (_cnt669 >= 1) { goto _loop669_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt680 >= 1) { goto _loop680_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt669++;
+				_cnt680++;
 			}
-_loop669_breakloop:			;
+_loop680_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (0==inputState.guessing)
@@ -3147,7 +3149,7 @@ _loop669_breakloop:			;
 			case '8':  case '9':
 			{
 				{ // ( ... )+
-					int _cnt701=0;
+					int _cnt712=0;
 					for (;;)
 					{
 						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_5_.member(cached_LA2)) && (true))
@@ -3156,12 +3158,12 @@ _loop669_breakloop:			;
 						}
 						else
 						{
-							if (_cnt701 >= 1) { goto _loop701_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt712 >= 1) { goto _loop712_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt701++;
+						_cnt712++;
 					}
-_loop701_breakloop:					;
+_loop712_breakloop:					;
 				}    // ( ... )+
 				break;
 			}
