@@ -66,6 +66,18 @@ namespace BooCompiler.Tests
 			RunCompilerTestCase(@"extensions-9.boo");
 		}
 		
+		[Test]
+		public void extensions_for_self_1()
+		{
+			RunCompilerTestCase(@"extensions-for-self-1.boo");
+		}
+		
+		[Test]
+		public void extensions_for_self_2()
+		{
+			RunCompilerTestCase(@"extensions-for-self-2.boo");
+		}
+		
 		[Test]
 		public void implicit_conversion_extension_1()
 		{
