@@ -19,6 +19,12 @@ namespace BooCompiler.Tests
 			RunCompilerTestCase(@"debug-1.boo");
 		}
 		
+		[Test]
+		public void macro_1()
+		{
+			RunCompilerTestCase(@"macro-1.boo");
+		}
+		
 		[Test]
 		public void print_1()
 		{
