@@ -18,6 +18,12 @@ namespace BooCompiler.Tests
 			RunCompilerTestCase(@"BCE0138-1.boo");
 		}
 		
+		[Test]
+		public void BCE0138_2()
+		{
+			RunCompilerTestCase(@"BCE0138-2.boo");
+		}
+		
 		[Test]
 		public void BCE0139_1()
 		{
@@ -30,6 +36,24 @@ namespace BooCompiler.Tests
 			RunCompilerTestCase(@"BCE0139-2.boo");
 		}
 		
+		[Test]
+		public void BCE0139_3()
+		{
+			RunCompilerTestCase(@"BCE0139-3.boo");
+		}
+		
+		[Test]
+		public void BCE0147_external()
+		{
+			RunCompilerTestCase(@"BCE0147-external.boo");
+		}
+		
+		[Test]
+		public void BCE0149_external()
+		{
+			RunCompilerTestCase(@"BCE0149-external.boo");
+		}
+		
 
 		override protected string GetRelativeTestCasesPath()
 		{
