@@ -558,6 +558,12 @@ namespace BooCompiler.Tests
 			RunCompilerTestCase(@"interfaces-21.boo");
 		}
 		
+		[Test]
+		public void interfaces_22()
+		{
+			RunCompilerTestCase(@"interfaces-22.boo");
+		}
+		
 		[Test]
 		public void interfaces_3()
 		{
@@ -690,6 +696,18 @@ namespace BooCompiler.Tests
 			RunCompilerTestCase(@"overloading-6.boo");
 		}
 		
+		[Test]
+		public void overloading_7()
+		{
+			RunCompilerTestCase(@"overloading-7.boo");
+		}
+		
+		[Test]
+		public void overloading_8()
+		{
+			RunCompilerTestCase(@"overloading-8.boo");
+		}
+		
 		[Test]
 		public void override_1()
 		{
@@ -930,6 +948,18 @@ namespace BooCompiler.Tests
 			RunCompilerTestCase(@"properties-9.boo");
 		}
 		
+		[Test]
+		public void static_1()
+		{
+			RunCompilerTestCase(@"static-1.boo");
+		}
+		
+		[Test]
+		public void static_2()
+		{
+			RunCompilerTestCase(@"static-2.boo");
+		}
+		
 		[Test]
 		public void static_final_1()
 		{
